/**************************************************************************
**                                                                      **
** Copyright (C) 2011-2026 Lukas Spies                                  **
** Contact: https://photoqt.org                                         **
**                                                                      **
** This file is part of PhotoQt.                                        **
**                                                                      **
** PhotoQt is free software: you can redistribute it and/or modify      **
** it under the terms of the GNU General Public License as published by **
** the Free Software Foundation, either version 2 of the License, or    **
** (at your option) any later version.                                  **
**                                                                      **
** PhotoQt is distributed in the hope that it will be useful,           **
** but WITHOUT ANY WARRANTY; without even the implied warranty of       **
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        **
** GNU General Public License for more details.                         **
**                                                                      **
** You should have received a copy of the GNU General Public License    **
** along with PhotoQt. If not, see <http://www.gnu.org/licenses/>.      **
**                                                                      **
**************************************************************************/

/**//**//**//**//**//**//**//**//**//**//**//**//**//**//**/
//
// WARNING
// THIS FILE IS AUTO GENERATED BY `misc/pqc_settings.py`.
// ANY CHANGES HERE WILL BE OVERWRITTEN AT SOME POINT!
//
/**//**//**//**//**//**//**//**//**//**//**//**//**//**//**/

#pragma once

#include <QObject>
#include <QSqlDatabase>
#include <QQmlEngine>
#include <QQmlPropertyMap>
#include <QPoint>
#include <QSize>
#include <QTimer>

class PQCSettings : public QObject {

    Q_OBJECT
    QML_ELEMENT
    QML_SINGLETON

public:
    explicit PQCSettings(bool validateonly);
    explicit PQCSettings();
    ~PQCSettings();

    /**************************************/
    // table: filedialog

    Q_PROPERTY(bool filedialogDetailsTooltip READ getFiledialogDetailsTooltip WRITE setFiledialogDetailsTooltip NOTIFY filedialogDetailsTooltipChanged)
    bool getFiledialogDetailsTooltip() const;
    void setFiledialogDetailsTooltip(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogDetailsTooltip() const;
    Q_INVOKABLE void setDefaultForFiledialogDetailsTooltip();

    Q_PROPERTY(bool filedialogDevices READ getFiledialogDevices WRITE setFiledialogDevices NOTIFY filedialogDevicesChanged)
    bool getFiledialogDevices() const;
    void setFiledialogDevices(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogDevices() const;
    Q_INVOKABLE void setDefaultForFiledialogDevices();

    Q_PROPERTY(bool filedialogDevicesShowTmpfs READ getFiledialogDevicesShowTmpfs WRITE setFiledialogDevicesShowTmpfs NOTIFY filedialogDevicesShowTmpfsChanged)
    bool getFiledialogDevicesShowTmpfs() const;
    void setFiledialogDevicesShowTmpfs(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogDevicesShowTmpfs() const;
    Q_INVOKABLE void setDefaultForFiledialogDevicesShowTmpfs();

    Q_PROPERTY(bool filedialogDragDropFileviewGrid READ getFiledialogDragDropFileviewGrid WRITE setFiledialogDragDropFileviewGrid NOTIFY filedialogDragDropFileviewGridChanged)
    bool getFiledialogDragDropFileviewGrid() const;
    void setFiledialogDragDropFileviewGrid(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogDragDropFileviewGrid() const;
    Q_INVOKABLE void setDefaultForFiledialogDragDropFileviewGrid();

    Q_PROPERTY(bool filedialogDragDropFileviewList READ getFiledialogDragDropFileviewList WRITE setFiledialogDragDropFileviewList NOTIFY filedialogDragDropFileviewListChanged)
    bool getFiledialogDragDropFileviewList() const;
    void setFiledialogDragDropFileviewList(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogDragDropFileviewList() const;
    Q_INVOKABLE void setDefaultForFiledialogDragDropFileviewList();

    Q_PROPERTY(bool filedialogDragDropFileviewMasonry READ getFiledialogDragDropFileviewMasonry WRITE setFiledialogDragDropFileviewMasonry NOTIFY filedialogDragDropFileviewMasonryChanged)
    bool getFiledialogDragDropFileviewMasonry() const;
    void setFiledialogDragDropFileviewMasonry(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogDragDropFileviewMasonry() const;
    Q_INVOKABLE void setDefaultForFiledialogDragDropFileviewMasonry();

    Q_PROPERTY(bool filedialogDragDropPlaces READ getFiledialogDragDropPlaces WRITE setFiledialogDragDropPlaces NOTIFY filedialogDragDropPlacesChanged)
    bool getFiledialogDragDropPlaces() const;
    void setFiledialogDragDropPlaces(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogDragDropPlaces() const;
    Q_INVOKABLE void setDefaultForFiledialogDragDropPlaces();

    Q_PROPERTY(int filedialogElementPadding READ getFiledialogElementPadding WRITE setFiledialogElementPadding NOTIFY filedialogElementPaddingChanged)
    int getFiledialogElementPadding() const;
    void setFiledialogElementPadding(const int val);
    Q_INVOKABLE const int getDefaultForFiledialogElementPadding() const;
    Q_INVOKABLE void setDefaultForFiledialogElementPadding();

    Q_PROPERTY(bool filedialogFolderContentThumbnails READ getFiledialogFolderContentThumbnails WRITE setFiledialogFolderContentThumbnails NOTIFY filedialogFolderContentThumbnailsChanged)
    bool getFiledialogFolderContentThumbnails() const;
    void setFiledialogFolderContentThumbnails(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogFolderContentThumbnails() const;
    Q_INVOKABLE void setDefaultForFiledialogFolderContentThumbnails();

    Q_PROPERTY(bool filedialogFolderContentThumbnailsAutoload READ getFiledialogFolderContentThumbnailsAutoload WRITE setFiledialogFolderContentThumbnailsAutoload NOTIFY filedialogFolderContentThumbnailsAutoloadChanged)
    bool getFiledialogFolderContentThumbnailsAutoload() const;
    void setFiledialogFolderContentThumbnailsAutoload(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogFolderContentThumbnailsAutoload() const;
    Q_INVOKABLE void setDefaultForFiledialogFolderContentThumbnailsAutoload();

    Q_PROPERTY(bool filedialogFolderContentThumbnailsLoop READ getFiledialogFolderContentThumbnailsLoop WRITE setFiledialogFolderContentThumbnailsLoop NOTIFY filedialogFolderContentThumbnailsLoopChanged)
    bool getFiledialogFolderContentThumbnailsLoop() const;
    void setFiledialogFolderContentThumbnailsLoop(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogFolderContentThumbnailsLoop() const;
    Q_INVOKABLE void setDefaultForFiledialogFolderContentThumbnailsLoop();

    Q_PROPERTY(bool filedialogFolderContentThumbnailsScaleCrop READ getFiledialogFolderContentThumbnailsScaleCrop WRITE setFiledialogFolderContentThumbnailsScaleCrop NOTIFY filedialogFolderContentThumbnailsScaleCropChanged)
    bool getFiledialogFolderContentThumbnailsScaleCrop() const;
    void setFiledialogFolderContentThumbnailsScaleCrop(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogFolderContentThumbnailsScaleCrop() const;
    Q_INVOKABLE void setDefaultForFiledialogFolderContentThumbnailsScaleCrop();

    Q_PROPERTY(bool filedialogFolderContentThumbnailsSortAscending READ getFiledialogFolderContentThumbnailsSortAscending WRITE setFiledialogFolderContentThumbnailsSortAscending NOTIFY filedialogFolderContentThumbnailsSortAscendingChanged)
    bool getFiledialogFolderContentThumbnailsSortAscending() const;
    void setFiledialogFolderContentThumbnailsSortAscending(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogFolderContentThumbnailsSortAscending() const;
    Q_INVOKABLE void setDefaultForFiledialogFolderContentThumbnailsSortAscending();

    Q_PROPERTY(QString filedialogFolderContentThumbnailsSortBy READ getFiledialogFolderContentThumbnailsSortBy WRITE setFiledialogFolderContentThumbnailsSortBy NOTIFY filedialogFolderContentThumbnailsSortByChanged)
    QString getFiledialogFolderContentThumbnailsSortBy() const;
    void setFiledialogFolderContentThumbnailsSortBy(const QString val);
    Q_INVOKABLE const QString getDefaultForFiledialogFolderContentThumbnailsSortBy() const;
    Q_INVOKABLE void setDefaultForFiledialogFolderContentThumbnailsSortBy();

    Q_PROPERTY(int filedialogFolderContentThumbnailsSpeed READ getFiledialogFolderContentThumbnailsSpeed WRITE setFiledialogFolderContentThumbnailsSpeed NOTIFY filedialogFolderContentThumbnailsSpeedChanged)
    int getFiledialogFolderContentThumbnailsSpeed() const;
    void setFiledialogFolderContentThumbnailsSpeed(const int val);
    Q_INVOKABLE const int getDefaultForFiledialogFolderContentThumbnailsSpeed() const;
    Q_INVOKABLE void setDefaultForFiledialogFolderContentThumbnailsSpeed();

    Q_PROPERTY(bool filedialogLabelsShowGrid READ getFiledialogLabelsShowGrid WRITE setFiledialogLabelsShowGrid NOTIFY filedialogLabelsShowGridChanged)
    bool getFiledialogLabelsShowGrid() const;
    void setFiledialogLabelsShowGrid(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogLabelsShowGrid() const;
    Q_INVOKABLE void setDefaultForFiledialogLabelsShowGrid();

    Q_PROPERTY(bool filedialogLabelsShowMasonry READ getFiledialogLabelsShowMasonry WRITE setFiledialogLabelsShowMasonry NOTIFY filedialogLabelsShowMasonryChanged)
    bool getFiledialogLabelsShowMasonry() const;
    void setFiledialogLabelsShowMasonry(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogLabelsShowMasonry() const;
    Q_INVOKABLE void setDefaultForFiledialogLabelsShowMasonry();

    Q_PROPERTY(QString filedialogLayout READ getFiledialogLayout WRITE setFiledialogLayout NOTIFY filedialogLayoutChanged)
    QString getFiledialogLayout() const;
    void setFiledialogLayout(const QString val);
    Q_INVOKABLE const QString getDefaultForFiledialogLayout() const;
    Q_INVOKABLE void setDefaultForFiledialogLayout();

    Q_PROPERTY(bool filedialogPlaces READ getFiledialogPlaces WRITE setFiledialogPlaces NOTIFY filedialogPlacesChanged)
    bool getFiledialogPlaces() const;
    void setFiledialogPlaces(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogPlaces() const;
    Q_INVOKABLE void setDefaultForFiledialogPlaces();

    Q_PROPERTY(int filedialogPlacesWidth READ getFiledialogPlacesWidth WRITE setFiledialogPlacesWidth NOTIFY filedialogPlacesWidthChanged)
    int getFiledialogPlacesWidth() const;
    void setFiledialogPlacesWidth(const int val);
    Q_INVOKABLE const int getDefaultForFiledialogPlacesWidth() const;
    Q_INVOKABLE void setDefaultForFiledialogPlacesWidth();

    Q_PROPERTY(bool filedialogPreview READ getFiledialogPreview WRITE setFiledialogPreview NOTIFY filedialogPreviewChanged)
    bool getFiledialogPreview() const;
    void setFiledialogPreview(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogPreview() const;
    Q_INVOKABLE void setDefaultForFiledialogPreview();

    Q_PROPERTY(bool filedialogPreviewBlur READ getFiledialogPreviewBlur WRITE setFiledialogPreviewBlur NOTIFY filedialogPreviewBlurChanged)
    bool getFiledialogPreviewBlur() const;
    void setFiledialogPreviewBlur(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogPreviewBlur() const;
    Q_INVOKABLE void setDefaultForFiledialogPreviewBlur();

    Q_PROPERTY(int filedialogPreviewColorIntensity READ getFiledialogPreviewColorIntensity WRITE setFiledialogPreviewColorIntensity NOTIFY filedialogPreviewColorIntensityChanged)
    int getFiledialogPreviewColorIntensity() const;
    void setFiledialogPreviewColorIntensity(const int val);
    Q_INVOKABLE const int getDefaultForFiledialogPreviewColorIntensity() const;
    Q_INVOKABLE void setDefaultForFiledialogPreviewColorIntensity();

    Q_PROPERTY(bool filedialogPreviewCropToFit READ getFiledialogPreviewCropToFit WRITE setFiledialogPreviewCropToFit NOTIFY filedialogPreviewCropToFitChanged)
    bool getFiledialogPreviewCropToFit() const;
    void setFiledialogPreviewCropToFit(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogPreviewCropToFit() const;
    Q_INVOKABLE void setDefaultForFiledialogPreviewCropToFit();

    Q_PROPERTY(bool filedialogPreviewHigherResolution READ getFiledialogPreviewHigherResolution WRITE setFiledialogPreviewHigherResolution NOTIFY filedialogPreviewHigherResolutionChanged)
    bool getFiledialogPreviewHigherResolution() const;
    void setFiledialogPreviewHigherResolution(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogPreviewHigherResolution() const;
    Q_INVOKABLE void setDefaultForFiledialogPreviewHigherResolution();

    Q_PROPERTY(bool filedialogPreviewMuted READ getFiledialogPreviewMuted WRITE setFiledialogPreviewMuted NOTIFY filedialogPreviewMutedChanged)
    bool getFiledialogPreviewMuted() const;
    void setFiledialogPreviewMuted(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogPreviewMuted() const;
    Q_INVOKABLE void setDefaultForFiledialogPreviewMuted();

    Q_PROPERTY(bool filedialogRememberSelection READ getFiledialogRememberSelection WRITE setFiledialogRememberSelection NOTIFY filedialogRememberSelectionChanged)
    bool getFiledialogRememberSelection() const;
    void setFiledialogRememberSelection(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogRememberSelection() const;
    Q_INVOKABLE void setDefaultForFiledialogRememberSelection();

    Q_PROPERTY(bool filedialogShowHiddenFilesFolders READ getFiledialogShowHiddenFilesFolders WRITE setFiledialogShowHiddenFilesFolders NOTIFY filedialogShowHiddenFilesFoldersChanged)
    bool getFiledialogShowHiddenFilesFolders() const;
    void setFiledialogShowHiddenFilesFolders(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogShowHiddenFilesFolders() const;
    Q_INVOKABLE void setDefaultForFiledialogShowHiddenFilesFolders();

    Q_PROPERTY(bool filedialogSingleClickSelect READ getFiledialogSingleClickSelect WRITE setFiledialogSingleClickSelect NOTIFY filedialogSingleClickSelectChanged)
    bool getFiledialogSingleClickSelect() const;
    void setFiledialogSingleClickSelect(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogSingleClickSelect() const;
    Q_INVOKABLE void setDefaultForFiledialogSingleClickSelect();

    Q_PROPERTY(bool filedialogStartupRestoreCustom READ getFiledialogStartupRestoreCustom WRITE setFiledialogStartupRestoreCustom NOTIFY filedialogStartupRestoreCustomChanged)
    bool getFiledialogStartupRestoreCustom() const;
    void setFiledialogStartupRestoreCustom(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogStartupRestoreCustom() const;
    Q_INVOKABLE void setDefaultForFiledialogStartupRestoreCustom();

    Q_PROPERTY(QString filedialogStartupRestoreCustomFolder READ getFiledialogStartupRestoreCustomFolder WRITE setFiledialogStartupRestoreCustomFolder NOTIFY filedialogStartupRestoreCustomFolderChanged)
    QString getFiledialogStartupRestoreCustomFolder() const;
    void setFiledialogStartupRestoreCustomFolder(const QString val);
    Q_INVOKABLE const QString getDefaultForFiledialogStartupRestoreCustomFolder() const;
    Q_INVOKABLE void setDefaultForFiledialogStartupRestoreCustomFolder();

    Q_PROPERTY(bool filedialogStartupRestoreHome READ getFiledialogStartupRestoreHome WRITE setFiledialogStartupRestoreHome NOTIFY filedialogStartupRestoreHomeChanged)
    bool getFiledialogStartupRestoreHome() const;
    void setFiledialogStartupRestoreHome(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogStartupRestoreHome() const;
    Q_INVOKABLE void setDefaultForFiledialogStartupRestoreHome();

    Q_PROPERTY(bool filedialogStartupRestorePrevious READ getFiledialogStartupRestorePrevious WRITE setFiledialogStartupRestorePrevious NOTIFY filedialogStartupRestorePreviousChanged)
    bool getFiledialogStartupRestorePrevious() const;
    void setFiledialogStartupRestorePrevious(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogStartupRestorePrevious() const;
    Q_INVOKABLE void setDefaultForFiledialogStartupRestorePrevious();

    Q_PROPERTY(bool filedialogThumbnailSizeFollowsGlobalThumbnails READ getFiledialogThumbnailSizeFollowsGlobalThumbnails WRITE setFiledialogThumbnailSizeFollowsGlobalThumbnails NOTIFY filedialogThumbnailSizeFollowsGlobalThumbnailsChanged)
    bool getFiledialogThumbnailSizeFollowsGlobalThumbnails() const;
    void setFiledialogThumbnailSizeFollowsGlobalThumbnails(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogThumbnailSizeFollowsGlobalThumbnails() const;
    Q_INVOKABLE void setDefaultForFiledialogThumbnailSizeFollowsGlobalThumbnails();

    Q_PROPERTY(bool filedialogThumbnails READ getFiledialogThumbnails WRITE setFiledialogThumbnails NOTIFY filedialogThumbnailsChanged)
    bool getFiledialogThumbnails() const;
    void setFiledialogThumbnails(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogThumbnails() const;
    Q_INVOKABLE void setDefaultForFiledialogThumbnails();

    Q_PROPERTY(bool filedialogThumbnailsScaleCrop READ getFiledialogThumbnailsScaleCrop WRITE setFiledialogThumbnailsScaleCrop NOTIFY filedialogThumbnailsScaleCropChanged)
    bool getFiledialogThumbnailsScaleCrop() const;
    void setFiledialogThumbnailsScaleCrop(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogThumbnailsScaleCrop() const;
    Q_INVOKABLE void setDefaultForFiledialogThumbnailsScaleCrop();

    Q_PROPERTY(bool filedialogUseNativeFileDialog READ getFiledialogUseNativeFileDialog WRITE setFiledialogUseNativeFileDialog NOTIFY filedialogUseNativeFileDialogChanged)
    bool getFiledialogUseNativeFileDialog() const;
    void setFiledialogUseNativeFileDialog(const bool val);
    Q_INVOKABLE const bool getDefaultForFiledialogUseNativeFileDialog() const;
    Q_INVOKABLE void setDefaultForFiledialogUseNativeFileDialog();

    Q_PROPERTY(int filedialogZoom READ getFiledialogZoom WRITE setFiledialogZoom NOTIFY filedialogZoomChanged)
    int getFiledialogZoom() const;
    void setFiledialogZoom(const int val);
    Q_INVOKABLE const int getDefaultForFiledialogZoom() const;
    Q_INVOKABLE void setDefaultForFiledialogZoom();

    /**************************************/
    // table: filetypes

    Q_PROPERTY(bool filetypesAnimatedControls READ getFiletypesAnimatedControls WRITE setFiletypesAnimatedControls NOTIFY filetypesAnimatedControlsChanged)
    bool getFiletypesAnimatedControls() const;
    void setFiletypesAnimatedControls(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesAnimatedControls() const;
    Q_INVOKABLE void setDefaultForFiletypesAnimatedControls();

    Q_PROPERTY(bool filetypesAnimatedLeftRight READ getFiletypesAnimatedLeftRight WRITE setFiletypesAnimatedLeftRight NOTIFY filetypesAnimatedLeftRightChanged)
    bool getFiletypesAnimatedLeftRight() const;
    void setFiletypesAnimatedLeftRight(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesAnimatedLeftRight() const;
    Q_INVOKABLE void setDefaultForFiletypesAnimatedLeftRight();

    Q_PROPERTY(bool filetypesAnimatedSpacePause READ getFiletypesAnimatedSpacePause WRITE setFiletypesAnimatedSpacePause NOTIFY filetypesAnimatedSpacePauseChanged)
    bool getFiletypesAnimatedSpacePause() const;
    void setFiletypesAnimatedSpacePause(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesAnimatedSpacePause() const;
    Q_INVOKABLE void setDefaultForFiletypesAnimatedSpacePause();

    Q_PROPERTY(bool filetypesArchiveAlwaysEnterAutomatically READ getFiletypesArchiveAlwaysEnterAutomatically WRITE setFiletypesArchiveAlwaysEnterAutomatically NOTIFY filetypesArchiveAlwaysEnterAutomaticallyChanged)
    bool getFiletypesArchiveAlwaysEnterAutomatically() const;
    void setFiletypesArchiveAlwaysEnterAutomatically(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesArchiveAlwaysEnterAutomatically() const;
    Q_INVOKABLE void setDefaultForFiletypesArchiveAlwaysEnterAutomatically();

    Q_PROPERTY(bool filetypesArchiveControls READ getFiletypesArchiveControls WRITE setFiletypesArchiveControls NOTIFY filetypesArchiveControlsChanged)
    bool getFiletypesArchiveControls() const;
    void setFiletypesArchiveControls(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesArchiveControls() const;
    Q_INVOKABLE void setDefaultForFiletypesArchiveControls();

    Q_PROPERTY(bool filetypesArchiveDontLoadMoreFilesThan READ getFiletypesArchiveDontLoadMoreFilesThan WRITE setFiletypesArchiveDontLoadMoreFilesThan NOTIFY filetypesArchiveDontLoadMoreFilesThanChanged)
    bool getFiletypesArchiveDontLoadMoreFilesThan() const;
    void setFiletypesArchiveDontLoadMoreFilesThan(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesArchiveDontLoadMoreFilesThan() const;
    Q_INVOKABLE void setDefaultForFiletypesArchiveDontLoadMoreFilesThan();

    Q_PROPERTY(int filetypesArchiveDontLoadMoreFilesThanCount READ getFiletypesArchiveDontLoadMoreFilesThanCount WRITE setFiletypesArchiveDontLoadMoreFilesThanCount NOTIFY filetypesArchiveDontLoadMoreFilesThanCountChanged)
    int getFiletypesArchiveDontLoadMoreFilesThanCount() const;
    void setFiletypesArchiveDontLoadMoreFilesThanCount(const int val);
    Q_INVOKABLE const int getDefaultForFiletypesArchiveDontLoadMoreFilesThanCount() const;
    Q_INVOKABLE void setDefaultForFiletypesArchiveDontLoadMoreFilesThanCount();

    Q_PROPERTY(bool filetypesArchiveIgnoreLargerThan READ getFiletypesArchiveIgnoreLargerThan WRITE setFiletypesArchiveIgnoreLargerThan NOTIFY filetypesArchiveIgnoreLargerThanChanged)
    bool getFiletypesArchiveIgnoreLargerThan() const;
    void setFiletypesArchiveIgnoreLargerThan(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesArchiveIgnoreLargerThan() const;
    Q_INVOKABLE void setDefaultForFiletypesArchiveIgnoreLargerThan();

    Q_PROPERTY(int filetypesArchiveIgnoreLargerThanSize READ getFiletypesArchiveIgnoreLargerThanSize WRITE setFiletypesArchiveIgnoreLargerThanSize NOTIFY filetypesArchiveIgnoreLargerThanSizeChanged)
    int getFiletypesArchiveIgnoreLargerThanSize() const;
    void setFiletypesArchiveIgnoreLargerThanSize(const int val);
    Q_INVOKABLE const int getDefaultForFiletypesArchiveIgnoreLargerThanSize() const;
    Q_INVOKABLE void setDefaultForFiletypesArchiveIgnoreLargerThanSize();

    Q_PROPERTY(bool filetypesArchiveLeftRight READ getFiletypesArchiveLeftRight WRITE setFiletypesArchiveLeftRight NOTIFY filetypesArchiveLeftRightChanged)
    bool getFiletypesArchiveLeftRight() const;
    void setFiletypesArchiveLeftRight(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesArchiveLeftRight() const;
    Q_INVOKABLE void setDefaultForFiletypesArchiveLeftRight();

    Q_PROPERTY(bool filetypesArchiveViewerModeExitButton READ getFiletypesArchiveViewerModeExitButton WRITE setFiletypesArchiveViewerModeExitButton NOTIFY filetypesArchiveViewerModeExitButtonChanged)
    bool getFiletypesArchiveViewerModeExitButton() const;
    void setFiletypesArchiveViewerModeExitButton(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesArchiveViewerModeExitButton() const;
    Q_INVOKABLE void setDefaultForFiletypesArchiveViewerModeExitButton();

    Q_PROPERTY(bool filetypesComicBookAlwaysEnterAutomatically READ getFiletypesComicBookAlwaysEnterAutomatically WRITE setFiletypesComicBookAlwaysEnterAutomatically NOTIFY filetypesComicBookAlwaysEnterAutomaticallyChanged)
    bool getFiletypesComicBookAlwaysEnterAutomatically() const;
    void setFiletypesComicBookAlwaysEnterAutomatically(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesComicBookAlwaysEnterAutomatically() const;
    Q_INVOKABLE void setDefaultForFiletypesComicBookAlwaysEnterAutomatically();

    Q_PROPERTY(bool filetypesDocumentAlwaysEnterAutomatically READ getFiletypesDocumentAlwaysEnterAutomatically WRITE setFiletypesDocumentAlwaysEnterAutomatically NOTIFY filetypesDocumentAlwaysEnterAutomaticallyChanged)
    bool getFiletypesDocumentAlwaysEnterAutomatically() const;
    void setFiletypesDocumentAlwaysEnterAutomatically(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesDocumentAlwaysEnterAutomatically() const;
    Q_INVOKABLE void setDefaultForFiletypesDocumentAlwaysEnterAutomatically();

    Q_PROPERTY(bool filetypesDocumentControls READ getFiletypesDocumentControls WRITE setFiletypesDocumentControls NOTIFY filetypesDocumentControlsChanged)
    bool getFiletypesDocumentControls() const;
    void setFiletypesDocumentControls(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesDocumentControls() const;
    Q_INVOKABLE void setDefaultForFiletypesDocumentControls();

    Q_PROPERTY(bool filetypesDocumentLeftRight READ getFiletypesDocumentLeftRight WRITE setFiletypesDocumentLeftRight NOTIFY filetypesDocumentLeftRightChanged)
    bool getFiletypesDocumentLeftRight() const;
    void setFiletypesDocumentLeftRight(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesDocumentLeftRight() const;
    Q_INVOKABLE void setDefaultForFiletypesDocumentLeftRight();

    Q_PROPERTY(bool filetypesDocumentViewerModeExitButton READ getFiletypesDocumentViewerModeExitButton WRITE setFiletypesDocumentViewerModeExitButton NOTIFY filetypesDocumentViewerModeExitButtonChanged)
    bool getFiletypesDocumentViewerModeExitButton() const;
    void setFiletypesDocumentViewerModeExitButton(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesDocumentViewerModeExitButton() const;
    Q_INVOKABLE void setDefaultForFiletypesDocumentViewerModeExitButton();

    Q_PROPERTY(bool filetypesExternalUnrar READ getFiletypesExternalUnrar WRITE setFiletypesExternalUnrar NOTIFY filetypesExternalUnrarChanged)
    bool getFiletypesExternalUnrar() const;
    void setFiletypesExternalUnrar(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesExternalUnrar() const;
    Q_INVOKABLE void setDefaultForFiletypesExternalUnrar();

    Q_PROPERTY(bool filetypesLoadAppleLivePhotos READ getFiletypesLoadAppleLivePhotos WRITE setFiletypesLoadAppleLivePhotos NOTIFY filetypesLoadAppleLivePhotosChanged)
    bool getFiletypesLoadAppleLivePhotos() const;
    void setFiletypesLoadAppleLivePhotos(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesLoadAppleLivePhotos() const;
    Q_INVOKABLE void setDefaultForFiletypesLoadAppleLivePhotos();

    Q_PROPERTY(bool filetypesLoadMotionPhotos READ getFiletypesLoadMotionPhotos WRITE setFiletypesLoadMotionPhotos NOTIFY filetypesLoadMotionPhotosChanged)
    bool getFiletypesLoadMotionPhotos() const;
    void setFiletypesLoadMotionPhotos(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesLoadMotionPhotos() const;
    Q_INVOKABLE void setDefaultForFiletypesLoadMotionPhotos();

    Q_PROPERTY(bool filetypesMotionAutoPlay READ getFiletypesMotionAutoPlay WRITE setFiletypesMotionAutoPlay NOTIFY filetypesMotionAutoPlayChanged)
    bool getFiletypesMotionAutoPlay() const;
    void setFiletypesMotionAutoPlay(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesMotionAutoPlay() const;
    Q_INVOKABLE void setDefaultForFiletypesMotionAutoPlay();

    Q_PROPERTY(bool filetypesMotionPhotoPlayPause READ getFiletypesMotionPhotoPlayPause WRITE setFiletypesMotionPhotoPlayPause NOTIFY filetypesMotionPhotoPlayPauseChanged)
    bool getFiletypesMotionPhotoPlayPause() const;
    void setFiletypesMotionPhotoPlayPause(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesMotionPhotoPlayPause() const;
    Q_INVOKABLE void setDefaultForFiletypesMotionPhotoPlayPause();

    Q_PROPERTY(bool filetypesMotionSpacePause READ getFiletypesMotionSpacePause WRITE setFiletypesMotionSpacePause NOTIFY filetypesMotionSpacePauseChanged)
    bool getFiletypesMotionSpacePause() const;
    void setFiletypesMotionSpacePause(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesMotionSpacePause() const;
    Q_INVOKABLE void setDefaultForFiletypesMotionSpacePause();

    Q_PROPERTY(int filetypesPDFQuality READ getFiletypesPDFQuality WRITE setFiletypesPDFQuality NOTIFY filetypesPDFQualityChanged)
    int getFiletypesPDFQuality() const;
    void setFiletypesPDFQuality(const int val);
    Q_INVOKABLE const int getDefaultForFiletypesPDFQuality() const;
    Q_INVOKABLE void setDefaultForFiletypesPDFQuality();

    Q_PROPERTY(bool filetypesPhotoSphereArrowKeys READ getFiletypesPhotoSphereArrowKeys WRITE setFiletypesPhotoSphereArrowKeys NOTIFY filetypesPhotoSphereArrowKeysChanged)
    bool getFiletypesPhotoSphereArrowKeys() const;
    void setFiletypesPhotoSphereArrowKeys(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesPhotoSphereArrowKeys() const;
    Q_INVOKABLE void setDefaultForFiletypesPhotoSphereArrowKeys();

    Q_PROPERTY(bool filetypesPhotoSphereAutoLoad READ getFiletypesPhotoSphereAutoLoad WRITE setFiletypesPhotoSphereAutoLoad NOTIFY filetypesPhotoSphereAutoLoadChanged)
    bool getFiletypesPhotoSphereAutoLoad() const;
    void setFiletypesPhotoSphereAutoLoad(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesPhotoSphereAutoLoad() const;
    Q_INVOKABLE void setDefaultForFiletypesPhotoSphereAutoLoad();

    Q_PROPERTY(bool filetypesPhotoSphereBigButton READ getFiletypesPhotoSphereBigButton WRITE setFiletypesPhotoSphereBigButton NOTIFY filetypesPhotoSphereBigButtonChanged)
    bool getFiletypesPhotoSphereBigButton() const;
    void setFiletypesPhotoSphereBigButton(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesPhotoSphereBigButton() const;
    Q_INVOKABLE void setDefaultForFiletypesPhotoSphereBigButton();

    Q_PROPERTY(bool filetypesPhotoSphereControls READ getFiletypesPhotoSphereControls WRITE setFiletypesPhotoSphereControls NOTIFY filetypesPhotoSphereControlsChanged)
    bool getFiletypesPhotoSphereControls() const;
    void setFiletypesPhotoSphereControls(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesPhotoSphereControls() const;
    Q_INVOKABLE void setDefaultForFiletypesPhotoSphereControls();

    Q_PROPERTY(bool filetypesPhotoSpherePanOnLoad READ getFiletypesPhotoSpherePanOnLoad WRITE setFiletypesPhotoSpherePanOnLoad NOTIFY filetypesPhotoSpherePanOnLoadChanged)
    bool getFiletypesPhotoSpherePanOnLoad() const;
    void setFiletypesPhotoSpherePanOnLoad(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesPhotoSpherePanOnLoad() const;
    Q_INVOKABLE void setDefaultForFiletypesPhotoSpherePanOnLoad();

    Q_PROPERTY(bool filetypesRAWUseEmbeddedIfAvailable READ getFiletypesRAWUseEmbeddedIfAvailable WRITE setFiletypesRAWUseEmbeddedIfAvailable NOTIFY filetypesRAWUseEmbeddedIfAvailableChanged)
    bool getFiletypesRAWUseEmbeddedIfAvailable() const;
    void setFiletypesRAWUseEmbeddedIfAvailable(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesRAWUseEmbeddedIfAvailable() const;
    Q_INVOKABLE void setDefaultForFiletypesRAWUseEmbeddedIfAvailable();

    Q_PROPERTY(bool filetypesVideoAutoplay READ getFiletypesVideoAutoplay WRITE setFiletypesVideoAutoplay NOTIFY filetypesVideoAutoplayChanged)
    bool getFiletypesVideoAutoplay() const;
    void setFiletypesVideoAutoplay(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesVideoAutoplay() const;
    Q_INVOKABLE void setDefaultForFiletypesVideoAutoplay();

    Q_PROPERTY(QStringList filetypesVideoBackend READ getFiletypesVideoBackend WRITE setFiletypesVideoBackend NOTIFY filetypesVideoBackendChanged)
    QStringList getFiletypesVideoBackend() const;
    void setFiletypesVideoBackend(const QStringList val);
    Q_INVOKABLE const QStringList getDefaultForFiletypesVideoBackend() const;
    Q_INVOKABLE void setDefaultForFiletypesVideoBackend();

    Q_PROPERTY(bool filetypesVideoLeftRightJumpVideo READ getFiletypesVideoLeftRightJumpVideo WRITE setFiletypesVideoLeftRightJumpVideo NOTIFY filetypesVideoLeftRightJumpVideoChanged)
    bool getFiletypesVideoLeftRightJumpVideo() const;
    void setFiletypesVideoLeftRightJumpVideo(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesVideoLeftRightJumpVideo() const;
    Q_INVOKABLE void setDefaultForFiletypesVideoLeftRightJumpVideo();

    Q_PROPERTY(bool filetypesVideoLoop READ getFiletypesVideoLoop WRITE setFiletypesVideoLoop NOTIFY filetypesVideoLoopChanged)
    bool getFiletypesVideoLoop() const;
    void setFiletypesVideoLoop(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesVideoLoop() const;
    Q_INVOKABLE void setDefaultForFiletypesVideoLoop();

    Q_PROPERTY(bool filetypesVideoSpacePause READ getFiletypesVideoSpacePause WRITE setFiletypesVideoSpacePause NOTIFY filetypesVideoSpacePauseChanged)
    bool getFiletypesVideoSpacePause() const;
    void setFiletypesVideoSpacePause(const bool val);
    Q_INVOKABLE const bool getDefaultForFiletypesVideoSpacePause() const;
    Q_INVOKABLE void setDefaultForFiletypesVideoSpacePause();

    Q_PROPERTY(QString filetypesVideoThumbnailer READ getFiletypesVideoThumbnailer WRITE setFiletypesVideoThumbnailer NOTIFY filetypesVideoThumbnailerChanged)
    QString getFiletypesVideoThumbnailer() const;
    void setFiletypesVideoThumbnailer(const QString val);
    Q_INVOKABLE const QString getDefaultForFiletypesVideoThumbnailer() const;
    Q_INVOKABLE void setDefaultForFiletypesVideoThumbnailer();

    Q_PROPERTY(int filetypesVideoVolume READ getFiletypesVideoVolume WRITE setFiletypesVideoVolume NOTIFY filetypesVideoVolumeChanged)
    int getFiletypesVideoVolume() const;
    void setFiletypesVideoVolume(const int val);
    Q_INVOKABLE const int getDefaultForFiletypesVideoVolume() const;
    Q_INVOKABLE void setDefaultForFiletypesVideoVolume();

    /**************************************/
    // table: general

    Q_PROPERTY(bool generalAutoSaveSettings READ getGeneralAutoSaveSettings WRITE setGeneralAutoSaveSettings NOTIFY generalAutoSaveSettingsChanged)
    bool getGeneralAutoSaveSettings() const;
    void setGeneralAutoSaveSettings(const bool val);
    Q_INVOKABLE const bool getDefaultForGeneralAutoSaveSettings() const;
    Q_INVOKABLE void setDefaultForGeneralAutoSaveSettings();

    Q_PROPERTY(bool generalCompactSettings READ getGeneralCompactSettings WRITE setGeneralCompactSettings NOTIFY generalCompactSettingsChanged)
    bool getGeneralCompactSettings() const;
    void setGeneralCompactSettings(const bool val);
    Q_INVOKABLE const bool getDefaultForGeneralCompactSettings() const;
    Q_INVOKABLE void setDefaultForGeneralCompactSettings();

    Q_PROPERTY(bool generalDisableAllAnimations READ getGeneralDisableAllAnimations WRITE setGeneralDisableAllAnimations NOTIFY generalDisableAllAnimationsChanged)
    bool getGeneralDisableAllAnimations() const;
    void setGeneralDisableAllAnimations(const bool val);
    Q_INVOKABLE const bool getDefaultForGeneralDisableAllAnimations() const;
    Q_INVOKABLE void setDefaultForGeneralDisableAllAnimations();

    Q_PROPERTY(QStringList generalExtensionsAllowUntrusted READ getGeneralExtensionsAllowUntrusted WRITE setGeneralExtensionsAllowUntrusted NOTIFY generalExtensionsAllowUntrustedChanged)
    QStringList getGeneralExtensionsAllowUntrusted() const;
    void setGeneralExtensionsAllowUntrusted(const QStringList val);
    Q_INVOKABLE const QStringList getDefaultForGeneralExtensionsAllowUntrusted() const;
    Q_INVOKABLE void setDefaultForGeneralExtensionsAllowUntrusted();

    Q_PROPERTY(QStringList generalExtensionsEnabled READ getGeneralExtensionsEnabled WRITE setGeneralExtensionsEnabled NOTIFY generalExtensionsEnabledChanged)
    QStringList getGeneralExtensionsEnabled() const;
    void setGeneralExtensionsEnabled(const QStringList val);
    Q_INVOKABLE const QStringList getDefaultForGeneralExtensionsEnabled() const;
    Q_INVOKABLE void setDefaultForGeneralExtensionsEnabled();

    Q_PROPERTY(QStringList generalExtensionsFloatingSetup READ getGeneralExtensionsFloatingSetup WRITE setGeneralExtensionsFloatingSetup NOTIFY generalExtensionsFloatingSetupChanged)
    QStringList getGeneralExtensionsFloatingSetup() const;
    void setGeneralExtensionsFloatingSetup(const QStringList val);
    Q_INVOKABLE const QStringList getDefaultForGeneralExtensionsFloatingSetup() const;
    Q_INVOKABLE void setDefaultForGeneralExtensionsFloatingSetup();

    Q_PROPERTY(QString generalInterfaceVariant READ getGeneralInterfaceVariant WRITE setGeneralInterfaceVariant NOTIFY generalInterfaceVariantChanged)
    QString getGeneralInterfaceVariant() const;
    void setGeneralInterfaceVariant(const QString val);
    Q_INVOKABLE const QString getDefaultForGeneralInterfaceVariant() const;
    Q_INVOKABLE void setDefaultForGeneralInterfaceVariant();

    Q_PROPERTY(QString generalVersion READ getGeneralVersion WRITE setGeneralVersion NOTIFY generalVersionChanged)
    QString getGeneralVersion() const;
    void setGeneralVersion(const QString val);
    Q_INVOKABLE const QString getDefaultForGeneralVersion() const;
    Q_INVOKABLE void setDefaultForGeneralVersion();

    /**************************************/
    // table: imageview

    Q_PROPERTY(bool imageviewAdvancedSortAscending READ getImageviewAdvancedSortAscending WRITE setImageviewAdvancedSortAscending NOTIFY imageviewAdvancedSortAscendingChanged)
    bool getImageviewAdvancedSortAscending() const;
    void setImageviewAdvancedSortAscending(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewAdvancedSortAscending() const;
    Q_INVOKABLE void setDefaultForImageviewAdvancedSortAscending();

    Q_PROPERTY(QString imageviewAdvancedSortCriteria READ getImageviewAdvancedSortCriteria WRITE setImageviewAdvancedSortCriteria NOTIFY imageviewAdvancedSortCriteriaChanged)
    QString getImageviewAdvancedSortCriteria() const;
    void setImageviewAdvancedSortCriteria(const QString val);
    Q_INVOKABLE const QString getDefaultForImageviewAdvancedSortCriteria() const;
    Q_INVOKABLE void setDefaultForImageviewAdvancedSortCriteria();

    Q_PROPERTY(QStringList imageviewAdvancedSortDateCriteria READ getImageviewAdvancedSortDateCriteria WRITE setImageviewAdvancedSortDateCriteria NOTIFY imageviewAdvancedSortDateCriteriaChanged)
    QStringList getImageviewAdvancedSortDateCriteria() const;
    void setImageviewAdvancedSortDateCriteria(const QStringList val);
    Q_INVOKABLE const QStringList getDefaultForImageviewAdvancedSortDateCriteria() const;
    Q_INVOKABLE void setDefaultForImageviewAdvancedSortDateCriteria();

    Q_PROPERTY(QString imageviewAdvancedSortQuality READ getImageviewAdvancedSortQuality WRITE setImageviewAdvancedSortQuality NOTIFY imageviewAdvancedSortQualityChanged)
    QString getImageviewAdvancedSortQuality() const;
    void setImageviewAdvancedSortQuality(const QString val);
    Q_INVOKABLE const QString getDefaultForImageviewAdvancedSortQuality() const;
    Q_INVOKABLE void setDefaultForImageviewAdvancedSortQuality();

    Q_PROPERTY(bool imageviewAlwaysActualSize READ getImageviewAlwaysActualSize WRITE setImageviewAlwaysActualSize NOTIFY imageviewAlwaysActualSizeChanged)
    bool getImageviewAlwaysActualSize() const;
    void setImageviewAlwaysActualSize(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewAlwaysActualSize() const;
    Q_INVOKABLE void setDefaultForImageviewAlwaysActualSize();

    Q_PROPERTY(int imageviewAnimationDuration READ getImageviewAnimationDuration WRITE setImageviewAnimationDuration NOTIFY imageviewAnimationDurationChanged)
    int getImageviewAnimationDuration() const;
    void setImageviewAnimationDuration(const int val);
    Q_INVOKABLE const int getDefaultForImageviewAnimationDuration() const;
    Q_INVOKABLE void setDefaultForImageviewAnimationDuration();

    Q_PROPERTY(QString imageviewAnimationType READ getImageviewAnimationType WRITE setImageviewAnimationType NOTIFY imageviewAnimationTypeChanged)
    QString getImageviewAnimationType() const;
    void setImageviewAnimationType(const QString val);
    Q_INVOKABLE const QString getDefaultForImageviewAnimationType() const;
    Q_INVOKABLE void setDefaultForImageviewAnimationType();

    Q_PROPERTY(int imageviewCache READ getImageviewCache WRITE setImageviewCache NOTIFY imageviewCacheChanged)
    int getImageviewCache() const;
    void setImageviewCache(const int val);
    Q_INVOKABLE const int getDefaultForImageviewCache() const;
    Q_INVOKABLE void setDefaultForImageviewCache();

    Q_PROPERTY(QStringList imageviewColorSpaceContextMenu READ getImageviewColorSpaceContextMenu WRITE setImageviewColorSpaceContextMenu NOTIFY imageviewColorSpaceContextMenuChanged)
    QStringList getImageviewColorSpaceContextMenu() const;
    void setImageviewColorSpaceContextMenu(const QStringList val);
    Q_INVOKABLE const QStringList getDefaultForImageviewColorSpaceContextMenu() const;
    Q_INVOKABLE void setDefaultForImageviewColorSpaceContextMenu();

    Q_PROPERTY(QString imageviewColorSpaceDefault READ getImageviewColorSpaceDefault WRITE setImageviewColorSpaceDefault NOTIFY imageviewColorSpaceDefaultChanged)
    QString getImageviewColorSpaceDefault() const;
    void setImageviewColorSpaceDefault(const QString val);
    Q_INVOKABLE const QString getDefaultForImageviewColorSpaceDefault() const;
    Q_INVOKABLE void setDefaultForImageviewColorSpaceDefault();

    Q_PROPERTY(bool imageviewColorSpaceEnable READ getImageviewColorSpaceEnable WRITE setImageviewColorSpaceEnable NOTIFY imageviewColorSpaceEnableChanged)
    bool getImageviewColorSpaceEnable() const;
    void setImageviewColorSpaceEnable(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewColorSpaceEnable() const;
    Q_INVOKABLE void setDefaultForImageviewColorSpaceEnable();

    Q_PROPERTY(bool imageviewColorSpaceLoadEmbedded READ getImageviewColorSpaceLoadEmbedded WRITE setImageviewColorSpaceLoadEmbedded NOTIFY imageviewColorSpaceLoadEmbeddedChanged)
    bool getImageviewColorSpaceLoadEmbedded() const;
    void setImageviewColorSpaceLoadEmbedded(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewColorSpaceLoadEmbedded() const;
    Q_INVOKABLE void setDefaultForImageviewColorSpaceLoadEmbedded();

    Q_PROPERTY(bool imageviewEscapeExitArchive READ getImageviewEscapeExitArchive WRITE setImageviewEscapeExitArchive NOTIFY imageviewEscapeExitArchiveChanged)
    bool getImageviewEscapeExitArchive() const;
    void setImageviewEscapeExitArchive(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewEscapeExitArchive() const;
    Q_INVOKABLE void setDefaultForImageviewEscapeExitArchive();

    Q_PROPERTY(bool imageviewEscapeExitBarcodes READ getImageviewEscapeExitBarcodes WRITE setImageviewEscapeExitBarcodes NOTIFY imageviewEscapeExitBarcodesChanged)
    bool getImageviewEscapeExitBarcodes() const;
    void setImageviewEscapeExitBarcodes(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewEscapeExitBarcodes() const;
    Q_INVOKABLE void setDefaultForImageviewEscapeExitBarcodes();

    Q_PROPERTY(bool imageviewEscapeExitDocument READ getImageviewEscapeExitDocument WRITE setImageviewEscapeExitDocument NOTIFY imageviewEscapeExitDocumentChanged)
    bool getImageviewEscapeExitDocument() const;
    void setImageviewEscapeExitDocument(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewEscapeExitDocument() const;
    Q_INVOKABLE void setDefaultForImageviewEscapeExitDocument();

    Q_PROPERTY(bool imageviewEscapeExitFilter READ getImageviewEscapeExitFilter WRITE setImageviewEscapeExitFilter NOTIFY imageviewEscapeExitFilterChanged)
    bool getImageviewEscapeExitFilter() const;
    void setImageviewEscapeExitFilter(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewEscapeExitFilter() const;
    Q_INVOKABLE void setDefaultForImageviewEscapeExitFilter();

    Q_PROPERTY(bool imageviewEscapeExitSphere READ getImageviewEscapeExitSphere WRITE setImageviewEscapeExitSphere NOTIFY imageviewEscapeExitSphereChanged)
    bool getImageviewEscapeExitSphere() const;
    void setImageviewEscapeExitSphere(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewEscapeExitSphere() const;
    Q_INVOKABLE void setDefaultForImageviewEscapeExitSphere();

    Q_PROPERTY(bool imageviewFitInWindow READ getImageviewFitInWindow WRITE setImageviewFitInWindow NOTIFY imageviewFitInWindowChanged)
    bool getImageviewFitInWindow() const;
    void setImageviewFitInWindow(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewFitInWindow() const;
    Q_INVOKABLE void setDefaultForImageviewFitInWindow();

    Q_PROPERTY(int imageviewHideCursorTimeout READ getImageviewHideCursorTimeout WRITE setImageviewHideCursorTimeout NOTIFY imageviewHideCursorTimeoutChanged)
    int getImageviewHideCursorTimeout() const;
    void setImageviewHideCursorTimeout(const int val);
    Q_INVOKABLE const int getDefaultForImageviewHideCursorTimeout() const;
    Q_INVOKABLE void setDefaultForImageviewHideCursorTimeout();

    Q_PROPERTY(int imageviewInterpolationFullImage READ getImageviewInterpolationFullImage WRITE setImageviewInterpolationFullImage NOTIFY imageviewInterpolationFullImageChanged)
    int getImageviewInterpolationFullImage() const;
    void setImageviewInterpolationFullImage(const int val);
    Q_INVOKABLE const int getDefaultForImageviewInterpolationFullImage() const;
    Q_INVOKABLE void setDefaultForImageviewInterpolationFullImage();

    Q_PROPERTY(bool imageviewLoopThroughFolder READ getImageviewLoopThroughFolder WRITE setImageviewLoopThroughFolder NOTIFY imageviewLoopThroughFolderChanged)
    bool getImageviewLoopThroughFolder() const;
    void setImageviewLoopThroughFolder(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewLoopThroughFolder() const;
    Q_INVOKABLE void setDefaultForImageviewLoopThroughFolder();

    Q_PROPERTY(int imageviewMargin READ getImageviewMargin WRITE setImageviewMargin NOTIFY imageviewMarginChanged)
    int getImageviewMargin() const;
    void setImageviewMargin(const int val);
    Q_INVOKABLE const int getDefaultForImageviewMargin() const;
    Q_INVOKABLE void setDefaultForImageviewMargin();

    Q_PROPERTY(int imageviewMinimapSizeLevel READ getImageviewMinimapSizeLevel WRITE setImageviewMinimapSizeLevel NOTIFY imageviewMinimapSizeLevelChanged)
    int getImageviewMinimapSizeLevel() const;
    void setImageviewMinimapSizeLevel(const int val);
    Q_INVOKABLE const int getDefaultForImageviewMinimapSizeLevel() const;
    Q_INVOKABLE void setDefaultForImageviewMinimapSizeLevel();

    Q_PROPERTY(bool imageviewMirrorAnimate READ getImageviewMirrorAnimate WRITE setImageviewMirrorAnimate NOTIFY imageviewMirrorAnimateChanged)
    bool getImageviewMirrorAnimate() const;
    void setImageviewMirrorAnimate(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewMirrorAnimate() const;
    Q_INVOKABLE void setDefaultForImageviewMirrorAnimate();

    Q_PROPERTY(int imageviewMouseWheelRepeatDelay READ getImageviewMouseWheelRepeatDelay WRITE setImageviewMouseWheelRepeatDelay NOTIFY imageviewMouseWheelRepeatDelayChanged)
    int getImageviewMouseWheelRepeatDelay() const;
    void setImageviewMouseWheelRepeatDelay(const int val);
    Q_INVOKABLE const int getDefaultForImageviewMouseWheelRepeatDelay() const;
    Q_INVOKABLE void setDefaultForImageviewMouseWheelRepeatDelay();

    Q_PROPERTY(int imageviewPreloadInBackground READ getImageviewPreloadInBackground WRITE setImageviewPreloadInBackground NOTIFY imageviewPreloadInBackgroundChanged)
    int getImageviewPreloadInBackground() const;
    void setImageviewPreloadInBackground(const int val);
    Q_INVOKABLE const int getDefaultForImageviewPreloadInBackground() const;
    Q_INVOKABLE void setDefaultForImageviewPreloadInBackground();

    Q_PROPERTY(bool imageviewPreserveMirror READ getImageviewPreserveMirror WRITE setImageviewPreserveMirror NOTIFY imageviewPreserveMirrorChanged)
    bool getImageviewPreserveMirror() const;
    void setImageviewPreserveMirror(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewPreserveMirror() const;
    Q_INVOKABLE void setDefaultForImageviewPreserveMirror();

    Q_PROPERTY(bool imageviewPreserveRotation READ getImageviewPreserveRotation WRITE setImageviewPreserveRotation NOTIFY imageviewPreserveRotationChanged)
    bool getImageviewPreserveRotation() const;
    void setImageviewPreserveRotation(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewPreserveRotation() const;
    Q_INVOKABLE void setDefaultForImageviewPreserveRotation();

    Q_PROPERTY(bool imageviewPreserveZoom READ getImageviewPreserveZoom WRITE setImageviewPreserveZoom NOTIFY imageviewPreserveZoomChanged)
    bool getImageviewPreserveZoom() const;
    void setImageviewPreserveZoom(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewPreserveZoom() const;
    Q_INVOKABLE void setDefaultForImageviewPreserveZoom();

    Q_PROPERTY(bool imageviewRememberZoomRotationMirror READ getImageviewRememberZoomRotationMirror WRITE setImageviewRememberZoomRotationMirror NOTIFY imageviewRememberZoomRotationMirrorChanged)
    bool getImageviewRememberZoomRotationMirror() const;
    void setImageviewRememberZoomRotationMirror(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewRememberZoomRotationMirror() const;
    Q_INVOKABLE void setDefaultForImageviewRememberZoomRotationMirror();

    Q_PROPERTY(bool imageviewRescalingSmooth READ getImageviewRescalingSmooth WRITE setImageviewRescalingSmooth NOTIFY imageviewRescalingSmoothChanged)
    bool getImageviewRescalingSmooth() const;
    void setImageviewRescalingSmooth(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewRescalingSmooth() const;
    Q_INVOKABLE void setDefaultForImageviewRescalingSmooth();

    Q_PROPERTY(int imageviewRescalingWhichImages READ getImageviewRescalingWhichImages WRITE setImageviewRescalingWhichImages NOTIFY imageviewRescalingWhichImagesChanged)
    int getImageviewRescalingWhichImages() const;
    void setImageviewRescalingWhichImages(const int val);
    Q_INVOKABLE const int getDefaultForImageviewRescalingWhichImages() const;
    Q_INVOKABLE void setDefaultForImageviewRescalingWhichImages();

    Q_PROPERTY(int imageviewResetViewAutoHideTimeout READ getImageviewResetViewAutoHideTimeout WRITE setImageviewResetViewAutoHideTimeout NOTIFY imageviewResetViewAutoHideTimeoutChanged)
    int getImageviewResetViewAutoHideTimeout() const;
    void setImageviewResetViewAutoHideTimeout(const int val);
    Q_INVOKABLE const int getDefaultForImageviewResetViewAutoHideTimeout() const;
    Q_INVOKABLE void setDefaultForImageviewResetViewAutoHideTimeout();

    Q_PROPERTY(bool imageviewResetViewShow READ getImageviewResetViewShow WRITE setImageviewResetViewShow NOTIFY imageviewResetViewShowChanged)
    bool getImageviewResetViewShow() const;
    void setImageviewResetViewShow(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewResetViewShow() const;
    Q_INVOKABLE void setDefaultForImageviewResetViewShow();

    Q_PROPERTY(bool imageviewRespectDevicePixelRatio READ getImageviewRespectDevicePixelRatio WRITE setImageviewRespectDevicePixelRatio NOTIFY imageviewRespectDevicePixelRatioChanged)
    bool getImageviewRespectDevicePixelRatio() const;
    void setImageviewRespectDevicePixelRatio(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewRespectDevicePixelRatio() const;
    Q_INVOKABLE void setDefaultForImageviewRespectDevicePixelRatio();

    Q_PROPERTY(bool imageviewShowMinimap READ getImageviewShowMinimap WRITE setImageviewShowMinimap NOTIFY imageviewShowMinimapChanged)
    bool getImageviewShowMinimap() const;
    void setImageviewShowMinimap(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewShowMinimap() const;
    Q_INVOKABLE void setDefaultForImageviewShowMinimap();

    Q_PROPERTY(int imageviewSiblingFileMaxIterations READ getImageviewSiblingFileMaxIterations WRITE setImageviewSiblingFileMaxIterations NOTIFY imageviewSiblingFileMaxIterationsChanged)
    int getImageviewSiblingFileMaxIterations() const;
    void setImageviewSiblingFileMaxIterations(const int val);
    Q_INVOKABLE const int getDefaultForImageviewSiblingFileMaxIterations() const;
    Q_INVOKABLE void setDefaultForImageviewSiblingFileMaxIterations();

    Q_PROPERTY(int imageviewSiblingFileMaxLevelUp READ getImageviewSiblingFileMaxLevelUp WRITE setImageviewSiblingFileMaxLevelUp NOTIFY imageviewSiblingFileMaxLevelUpChanged)
    int getImageviewSiblingFileMaxLevelUp() const;
    void setImageviewSiblingFileMaxLevelUp(const int val);
    Q_INVOKABLE const int getDefaultForImageviewSiblingFileMaxLevelUp() const;
    Q_INVOKABLE void setDefaultForImageviewSiblingFileMaxLevelUp();

    Q_PROPERTY(int imageviewSiblingFilemaxLevelDown READ getImageviewSiblingFilemaxLevelDown WRITE setImageviewSiblingFilemaxLevelDown NOTIFY imageviewSiblingFilemaxLevelDownChanged)
    int getImageviewSiblingFilemaxLevelDown() const;
    void setImageviewSiblingFilemaxLevelDown(const int val);
    Q_INVOKABLE const int getDefaultForImageviewSiblingFilemaxLevelDown() const;
    Q_INVOKABLE void setDefaultForImageviewSiblingFilemaxLevelDown();

    Q_PROPERTY(bool imageviewSortImagesAscending READ getImageviewSortImagesAscending WRITE setImageviewSortImagesAscending NOTIFY imageviewSortImagesAscendingChanged)
    bool getImageviewSortImagesAscending() const;
    void setImageviewSortImagesAscending(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewSortImagesAscending() const;
    Q_INVOKABLE void setDefaultForImageviewSortImagesAscending();

    Q_PROPERTY(QString imageviewSortImagesBy READ getImageviewSortImagesBy WRITE setImageviewSortImagesBy NOTIFY imageviewSortImagesByChanged)
    QString getImageviewSortImagesBy() const;
    void setImageviewSortImagesBy(const QString val);
    Q_INVOKABLE const QString getDefaultForImageviewSortImagesBy() const;
    Q_INVOKABLE void setDefaultForImageviewSortImagesBy();

    Q_PROPERTY(bool imageviewTransparencyMarker READ getImageviewTransparencyMarker WRITE setImageviewTransparencyMarker NOTIFY imageviewTransparencyMarkerChanged)
    bool getImageviewTransparencyMarker() const;
    void setImageviewTransparencyMarker(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewTransparencyMarker() const;
    Q_INVOKABLE void setDefaultForImageviewTransparencyMarker();

    Q_PROPERTY(bool imageviewUseMouseLeftButtonForImageMove READ getImageviewUseMouseLeftButtonForImageMove WRITE setImageviewUseMouseLeftButtonForImageMove NOTIFY imageviewUseMouseLeftButtonForImageMoveChanged)
    bool getImageviewUseMouseLeftButtonForImageMove() const;
    void setImageviewUseMouseLeftButtonForImageMove(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewUseMouseLeftButtonForImageMove() const;
    Q_INVOKABLE void setDefaultForImageviewUseMouseLeftButtonForImageMove();

    Q_PROPERTY(bool imageviewUseMouseWheelForImageMove READ getImageviewUseMouseWheelForImageMove WRITE setImageviewUseMouseWheelForImageMove NOTIFY imageviewUseMouseWheelForImageMoveChanged)
    bool getImageviewUseMouseWheelForImageMove() const;
    void setImageviewUseMouseWheelForImageMove(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewUseMouseWheelForImageMove() const;
    Q_INVOKABLE void setDefaultForImageviewUseMouseWheelForImageMove();

    Q_PROPERTY(int imageviewZoomMax READ getImageviewZoomMax WRITE setImageviewZoomMax NOTIFY imageviewZoomMaxChanged)
    int getImageviewZoomMax() const;
    void setImageviewZoomMax(const int val);
    Q_INVOKABLE const int getDefaultForImageviewZoomMax() const;
    Q_INVOKABLE void setDefaultForImageviewZoomMax();

    Q_PROPERTY(bool imageviewZoomMaxEnabled READ getImageviewZoomMaxEnabled WRITE setImageviewZoomMaxEnabled NOTIFY imageviewZoomMaxEnabledChanged)
    bool getImageviewZoomMaxEnabled() const;
    void setImageviewZoomMaxEnabled(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewZoomMaxEnabled() const;
    Q_INVOKABLE void setDefaultForImageviewZoomMaxEnabled();

    Q_PROPERTY(int imageviewZoomMin READ getImageviewZoomMin WRITE setImageviewZoomMin NOTIFY imageviewZoomMinChanged)
    int getImageviewZoomMin() const;
    void setImageviewZoomMin(const int val);
    Q_INVOKABLE const int getDefaultForImageviewZoomMin() const;
    Q_INVOKABLE void setDefaultForImageviewZoomMin();

    Q_PROPERTY(bool imageviewZoomMinEnabled READ getImageviewZoomMinEnabled WRITE setImageviewZoomMinEnabled NOTIFY imageviewZoomMinEnabledChanged)
    bool getImageviewZoomMinEnabled() const;
    void setImageviewZoomMinEnabled(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewZoomMinEnabled() const;
    Q_INVOKABLE void setDefaultForImageviewZoomMinEnabled();

    Q_PROPERTY(int imageviewZoomSpeed READ getImageviewZoomSpeed WRITE setImageviewZoomSpeed NOTIFY imageviewZoomSpeedChanged)
    int getImageviewZoomSpeed() const;
    void setImageviewZoomSpeed(const int val);
    Q_INVOKABLE const int getDefaultForImageviewZoomSpeed() const;
    Q_INVOKABLE void setDefaultForImageviewZoomSpeed();

    Q_PROPERTY(bool imageviewZoomSpeedRelative READ getImageviewZoomSpeedRelative WRITE setImageviewZoomSpeedRelative NOTIFY imageviewZoomSpeedRelativeChanged)
    bool getImageviewZoomSpeedRelative() const;
    void setImageviewZoomSpeedRelative(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewZoomSpeedRelative() const;
    Q_INVOKABLE void setDefaultForImageviewZoomSpeedRelative();

    Q_PROPERTY(bool imageviewZoomToCenter READ getImageviewZoomToCenter WRITE setImageviewZoomToCenter NOTIFY imageviewZoomToCenterChanged)
    bool getImageviewZoomToCenter() const;
    void setImageviewZoomToCenter(const bool val);
    Q_INVOKABLE const bool getDefaultForImageviewZoomToCenter() const;
    Q_INVOKABLE void setDefaultForImageviewZoomToCenter();

    /**************************************/
    // table: interface

    Q_PROPERTY(QString interfaceAccentColor READ getInterfaceAccentColor WRITE setInterfaceAccentColor NOTIFY interfaceAccentColorChanged)
    QString getInterfaceAccentColor() const;
    void setInterfaceAccentColor(const QString val);
    Q_INVOKABLE const QString getDefaultForInterfaceAccentColor() const;
    Q_INVOKABLE void setDefaultForInterfaceAccentColor();

    Q_PROPERTY(bool interfaceAllowMultipleInstances READ getInterfaceAllowMultipleInstances WRITE setInterfaceAllowMultipleInstances NOTIFY interfaceAllowMultipleInstancesChanged)
    bool getInterfaceAllowMultipleInstances() const;
    void setInterfaceAllowMultipleInstances(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceAllowMultipleInstances() const;
    Q_INVOKABLE void setDefaultForInterfaceAllowMultipleInstances();

    Q_PROPERTY(bool interfaceBackgroundCustomOverlay READ getInterfaceBackgroundCustomOverlay WRITE setInterfaceBackgroundCustomOverlay NOTIFY interfaceBackgroundCustomOverlayChanged)
    bool getInterfaceBackgroundCustomOverlay() const;
    void setInterfaceBackgroundCustomOverlay(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceBackgroundCustomOverlay() const;
    Q_INVOKABLE void setDefaultForInterfaceBackgroundCustomOverlay();

    Q_PROPERTY(QString interfaceBackgroundCustomOverlayColor READ getInterfaceBackgroundCustomOverlayColor WRITE setInterfaceBackgroundCustomOverlayColor NOTIFY interfaceBackgroundCustomOverlayColorChanged)
    QString getInterfaceBackgroundCustomOverlayColor() const;
    void setInterfaceBackgroundCustomOverlayColor(const QString val);
    Q_INVOKABLE const QString getDefaultForInterfaceBackgroundCustomOverlayColor() const;
    Q_INVOKABLE void setDefaultForInterfaceBackgroundCustomOverlayColor();

    Q_PROPERTY(bool interfaceBackgroundFullyTransparent READ getInterfaceBackgroundFullyTransparent WRITE setInterfaceBackgroundFullyTransparent NOTIFY interfaceBackgroundFullyTransparentChanged)
    bool getInterfaceBackgroundFullyTransparent() const;
    void setInterfaceBackgroundFullyTransparent(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceBackgroundFullyTransparent() const;
    Q_INVOKABLE void setDefaultForInterfaceBackgroundFullyTransparent();

    Q_PROPERTY(bool interfaceBackgroundImageCenter READ getInterfaceBackgroundImageCenter WRITE setInterfaceBackgroundImageCenter NOTIFY interfaceBackgroundImageCenterChanged)
    bool getInterfaceBackgroundImageCenter() const;
    void setInterfaceBackgroundImageCenter(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceBackgroundImageCenter() const;
    Q_INVOKABLE void setDefaultForInterfaceBackgroundImageCenter();

    Q_PROPERTY(QString interfaceBackgroundImagePath READ getInterfaceBackgroundImagePath WRITE setInterfaceBackgroundImagePath NOTIFY interfaceBackgroundImagePathChanged)
    QString getInterfaceBackgroundImagePath() const;
    void setInterfaceBackgroundImagePath(const QString val);
    Q_INVOKABLE const QString getDefaultForInterfaceBackgroundImagePath() const;
    Q_INVOKABLE void setDefaultForInterfaceBackgroundImagePath();

    Q_PROPERTY(bool interfaceBackgroundImageScale READ getInterfaceBackgroundImageScale WRITE setInterfaceBackgroundImageScale NOTIFY interfaceBackgroundImageScaleChanged)
    bool getInterfaceBackgroundImageScale() const;
    void setInterfaceBackgroundImageScale(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceBackgroundImageScale() const;
    Q_INVOKABLE void setDefaultForInterfaceBackgroundImageScale();

    Q_PROPERTY(bool interfaceBackgroundImageScaleCrop READ getInterfaceBackgroundImageScaleCrop WRITE setInterfaceBackgroundImageScaleCrop NOTIFY interfaceBackgroundImageScaleCropChanged)
    bool getInterfaceBackgroundImageScaleCrop() const;
    void setInterfaceBackgroundImageScaleCrop(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceBackgroundImageScaleCrop() const;
    Q_INVOKABLE void setDefaultForInterfaceBackgroundImageScaleCrop();

    Q_PROPERTY(bool interfaceBackgroundImageScreenshot READ getInterfaceBackgroundImageScreenshot WRITE setInterfaceBackgroundImageScreenshot NOTIFY interfaceBackgroundImageScreenshotChanged)
    bool getInterfaceBackgroundImageScreenshot() const;
    void setInterfaceBackgroundImageScreenshot(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceBackgroundImageScreenshot() const;
    Q_INVOKABLE void setDefaultForInterfaceBackgroundImageScreenshot();

    Q_PROPERTY(bool interfaceBackgroundImageStretch READ getInterfaceBackgroundImageStretch WRITE setInterfaceBackgroundImageStretch NOTIFY interfaceBackgroundImageStretchChanged)
    bool getInterfaceBackgroundImageStretch() const;
    void setInterfaceBackgroundImageStretch(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceBackgroundImageStretch() const;
    Q_INVOKABLE void setDefaultForInterfaceBackgroundImageStretch();

    Q_PROPERTY(bool interfaceBackgroundImageTile READ getInterfaceBackgroundImageTile WRITE setInterfaceBackgroundImageTile NOTIFY interfaceBackgroundImageTileChanged)
    bool getInterfaceBackgroundImageTile() const;
    void setInterfaceBackgroundImageTile(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceBackgroundImageTile() const;
    Q_INVOKABLE void setDefaultForInterfaceBackgroundImageTile();

    Q_PROPERTY(bool interfaceBackgroundImageUse READ getInterfaceBackgroundImageUse WRITE setInterfaceBackgroundImageUse NOTIFY interfaceBackgroundImageUseChanged)
    bool getInterfaceBackgroundImageUse() const;
    void setInterfaceBackgroundImageUse(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceBackgroundImageUse() const;
    Q_INVOKABLE void setDefaultForInterfaceBackgroundImageUse();

    Q_PROPERTY(bool interfaceBackgroundSolid READ getInterfaceBackgroundSolid WRITE setInterfaceBackgroundSolid NOTIFY interfaceBackgroundSolidChanged)
    bool getInterfaceBackgroundSolid() const;
    void setInterfaceBackgroundSolid(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceBackgroundSolid() const;
    Q_INVOKABLE void setDefaultForInterfaceBackgroundSolid();

    Q_PROPERTY(bool interfaceBlurElementsInBackground READ getInterfaceBlurElementsInBackground WRITE setInterfaceBlurElementsInBackground NOTIFY interfaceBlurElementsInBackgroundChanged)
    bool getInterfaceBlurElementsInBackground() const;
    void setInterfaceBlurElementsInBackground(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceBlurElementsInBackground() const;
    Q_INVOKABLE void setDefaultForInterfaceBlurElementsInBackground();

    Q_PROPERTY(bool interfaceCloseOnEmptyBackground READ getInterfaceCloseOnEmptyBackground WRITE setInterfaceCloseOnEmptyBackground NOTIFY interfaceCloseOnEmptyBackgroundChanged)
    bool getInterfaceCloseOnEmptyBackground() const;
    void setInterfaceCloseOnEmptyBackground(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceCloseOnEmptyBackground() const;
    Q_INVOKABLE void setDefaultForInterfaceCloseOnEmptyBackground();

    Q_PROPERTY(int interfaceDoubleClickThreshold READ getInterfaceDoubleClickThreshold WRITE setInterfaceDoubleClickThreshold NOTIFY interfaceDoubleClickThresholdChanged)
    int getInterfaceDoubleClickThreshold() const;
    void setInterfaceDoubleClickThreshold(const int val);
    Q_INVOKABLE const int getDefaultForInterfaceDoubleClickThreshold() const;
    Q_INVOKABLE void setDefaultForInterfaceDoubleClickThreshold();

    Q_PROPERTY(QString interfaceEdgeBottomAction READ getInterfaceEdgeBottomAction WRITE setInterfaceEdgeBottomAction NOTIFY interfaceEdgeBottomActionChanged)
    QString getInterfaceEdgeBottomAction() const;
    void setInterfaceEdgeBottomAction(const QString val);
    Q_INVOKABLE const QString getDefaultForInterfaceEdgeBottomAction() const;
    Q_INVOKABLE void setDefaultForInterfaceEdgeBottomAction();

    Q_PROPERTY(QString interfaceEdgeLeftAction READ getInterfaceEdgeLeftAction WRITE setInterfaceEdgeLeftAction NOTIFY interfaceEdgeLeftActionChanged)
    QString getInterfaceEdgeLeftAction() const;
    void setInterfaceEdgeLeftAction(const QString val);
    Q_INVOKABLE const QString getDefaultForInterfaceEdgeLeftAction() const;
    Q_INVOKABLE void setDefaultForInterfaceEdgeLeftAction();

    Q_PROPERTY(QString interfaceEdgeRightAction READ getInterfaceEdgeRightAction WRITE setInterfaceEdgeRightAction NOTIFY interfaceEdgeRightActionChanged)
    QString getInterfaceEdgeRightAction() const;
    void setInterfaceEdgeRightAction(const QString val);
    Q_INVOKABLE const QString getDefaultForInterfaceEdgeRightAction() const;
    Q_INVOKABLE void setDefaultForInterfaceEdgeRightAction();

    Q_PROPERTY(QString interfaceEdgeTopAction READ getInterfaceEdgeTopAction WRITE setInterfaceEdgeTopAction NOTIFY interfaceEdgeTopActionChanged)
    QString getInterfaceEdgeTopAction() const;
    void setInterfaceEdgeTopAction(const QString val);
    Q_INVOKABLE const QString getDefaultForInterfaceEdgeTopAction() const;
    Q_INVOKABLE void setDefaultForInterfaceEdgeTopAction();

    Q_PROPERTY(bool interfaceFlickAdjustSpeed READ getInterfaceFlickAdjustSpeed WRITE setInterfaceFlickAdjustSpeed NOTIFY interfaceFlickAdjustSpeedChanged)
    bool getInterfaceFlickAdjustSpeed() const;
    void setInterfaceFlickAdjustSpeed(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceFlickAdjustSpeed() const;
    Q_INVOKABLE void setDefaultForInterfaceFlickAdjustSpeed();

    Q_PROPERTY(int interfaceFlickAdjustSpeedSpeedup READ getInterfaceFlickAdjustSpeedSpeedup WRITE setInterfaceFlickAdjustSpeedSpeedup NOTIFY interfaceFlickAdjustSpeedSpeedupChanged)
    int getInterfaceFlickAdjustSpeedSpeedup() const;
    void setInterfaceFlickAdjustSpeedSpeedup(const int val);
    Q_INVOKABLE const int getDefaultForInterfaceFlickAdjustSpeedSpeedup() const;
    Q_INVOKABLE void setDefaultForInterfaceFlickAdjustSpeedSpeedup();

    Q_PROPERTY(int interfaceFontBoldWeight READ getInterfaceFontBoldWeight WRITE setInterfaceFontBoldWeight NOTIFY interfaceFontBoldWeightChanged)
    int getInterfaceFontBoldWeight() const;
    void setInterfaceFontBoldWeight(const int val);
    Q_INVOKABLE const int getDefaultForInterfaceFontBoldWeight() const;
    Q_INVOKABLE void setDefaultForInterfaceFontBoldWeight();

    Q_PROPERTY(int interfaceFontNormalWeight READ getInterfaceFontNormalWeight WRITE setInterfaceFontNormalWeight NOTIFY interfaceFontNormalWeightChanged)
    int getInterfaceFontNormalWeight() const;
    void setInterfaceFontNormalWeight(const int val);
    Q_INVOKABLE const int getDefaultForInterfaceFontNormalWeight() const;
    Q_INVOKABLE void setDefaultForInterfaceFontNormalWeight();

    Q_PROPERTY(int interfaceHotEdgeSize READ getInterfaceHotEdgeSize WRITE setInterfaceHotEdgeSize NOTIFY interfaceHotEdgeSizeChanged)
    int getInterfaceHotEdgeSize() const;
    void setInterfaceHotEdgeSize(const int val);
    Q_INVOKABLE const int getDefaultForInterfaceHotEdgeSize() const;
    Q_INVOKABLE void setDefaultForInterfaceHotEdgeSize();

    Q_PROPERTY(bool interfaceKeepWindowOnTop READ getInterfaceKeepWindowOnTop WRITE setInterfaceKeepWindowOnTop NOTIFY interfaceKeepWindowOnTopChanged)
    bool getInterfaceKeepWindowOnTop() const;
    void setInterfaceKeepWindowOnTop(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceKeepWindowOnTop() const;
    Q_INVOKABLE void setDefaultForInterfaceKeepWindowOnTop();

    Q_PROPERTY(QString interfaceLanguage READ getInterfaceLanguage WRITE setInterfaceLanguage NOTIFY interfaceLanguageChanged)
    QString getInterfaceLanguage() const;
    void setInterfaceLanguage(const QString val);
    Q_INVOKABLE const QString getDefaultForInterfaceLanguage() const;
    Q_INVOKABLE void setDefaultForInterfaceLanguage();

    Q_PROPERTY(bool interfaceMinimapPopout READ getInterfaceMinimapPopout WRITE setInterfaceMinimapPopout NOTIFY interfaceMinimapPopoutChanged)
    bool getInterfaceMinimapPopout() const;
    void setInterfaceMinimapPopout(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceMinimapPopout() const;
    Q_INVOKABLE void setDefaultForInterfaceMinimapPopout();

    Q_PROPERTY(bool interfaceNavigateOnEmptyBackground READ getInterfaceNavigateOnEmptyBackground WRITE setInterfaceNavigateOnEmptyBackground NOTIFY interfaceNavigateOnEmptyBackgroundChanged)
    bool getInterfaceNavigateOnEmptyBackground() const;
    void setInterfaceNavigateOnEmptyBackground(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceNavigateOnEmptyBackground() const;
    Q_INVOKABLE void setDefaultForInterfaceNavigateOnEmptyBackground();

    Q_PROPERTY(bool interfaceNavigationFloating READ getInterfaceNavigationFloating WRITE setInterfaceNavigationFloating NOTIFY interfaceNavigationFloatingChanged)
    bool getInterfaceNavigationFloating() const;
    void setInterfaceNavigationFloating(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceNavigationFloating() const;
    Q_INVOKABLE void setDefaultForInterfaceNavigationFloating();

    Q_PROPERTY(int interfaceNotificationDistanceFromEdge READ getInterfaceNotificationDistanceFromEdge WRITE setInterfaceNotificationDistanceFromEdge NOTIFY interfaceNotificationDistanceFromEdgeChanged)
    int getInterfaceNotificationDistanceFromEdge() const;
    void setInterfaceNotificationDistanceFromEdge(const int val);
    Q_INVOKABLE const int getDefaultForInterfaceNotificationDistanceFromEdge() const;
    Q_INVOKABLE void setDefaultForInterfaceNotificationDistanceFromEdge();

    Q_PROPERTY(QString interfaceNotificationLocation READ getInterfaceNotificationLocation WRITE setInterfaceNotificationLocation NOTIFY interfaceNotificationLocationChanged)
    QString getInterfaceNotificationLocation() const;
    void setInterfaceNotificationLocation(const QString val);
    Q_INVOKABLE const QString getDefaultForInterfaceNotificationLocation() const;
    Q_INVOKABLE void setDefaultForInterfaceNotificationLocation();

    Q_PROPERTY(bool interfaceNotificationTryNative READ getInterfaceNotificationTryNative WRITE setInterfaceNotificationTryNative NOTIFY interfaceNotificationTryNativeChanged)
    bool getInterfaceNotificationTryNative() const;
    void setInterfaceNotificationTryNative(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceNotificationTryNative() const;
    Q_INVOKABLE void setDefaultForInterfaceNotificationTryNative();

    Q_PROPERTY(bool interfacePopoutAbout READ getInterfacePopoutAbout WRITE setInterfacePopoutAbout NOTIFY interfacePopoutAboutChanged)
    bool getInterfacePopoutAbout() const;
    void setInterfacePopoutAbout(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutAbout() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutAbout();

    Q_PROPERTY(bool interfacePopoutAdvancedSort READ getInterfacePopoutAdvancedSort WRITE setInterfacePopoutAdvancedSort NOTIFY interfacePopoutAdvancedSortChanged)
    bool getInterfacePopoutAdvancedSort() const;
    void setInterfacePopoutAdvancedSort(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutAdvancedSort() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutAdvancedSort();

    Q_PROPERTY(bool interfacePopoutChromecast READ getInterfacePopoutChromecast WRITE setInterfacePopoutChromecast NOTIFY interfacePopoutChromecastChanged)
    bool getInterfacePopoutChromecast() const;
    void setInterfacePopoutChromecast(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutChromecast() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutChromecast();

    Q_PROPERTY(bool interfacePopoutExport READ getInterfacePopoutExport WRITE setInterfacePopoutExport NOTIFY interfacePopoutExportChanged)
    bool getInterfacePopoutExport() const;
    void setInterfacePopoutExport(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutExport() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutExport();

    Q_PROPERTY(bool interfacePopoutFileDelete READ getInterfacePopoutFileDelete WRITE setInterfacePopoutFileDelete NOTIFY interfacePopoutFileDeleteChanged)
    bool getInterfacePopoutFileDelete() const;
    void setInterfacePopoutFileDelete(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutFileDelete() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutFileDelete();

    Q_PROPERTY(bool interfacePopoutFileDialog READ getInterfacePopoutFileDialog WRITE setInterfacePopoutFileDialog NOTIFY interfacePopoutFileDialogChanged)
    bool getInterfacePopoutFileDialog() const;
    void setInterfacePopoutFileDialog(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutFileDialog() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutFileDialog();

    Q_PROPERTY(bool interfacePopoutFileDialogNonModal READ getInterfacePopoutFileDialogNonModal WRITE setInterfacePopoutFileDialogNonModal NOTIFY interfacePopoutFileDialogNonModalChanged)
    bool getInterfacePopoutFileDialogNonModal() const;
    void setInterfacePopoutFileDialogNonModal(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutFileDialogNonModal() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutFileDialogNonModal();

    Q_PROPERTY(bool interfacePopoutFileRename READ getInterfacePopoutFileRename WRITE setInterfacePopoutFileRename NOTIFY interfacePopoutFileRenameChanged)
    bool getInterfacePopoutFileRename() const;
    void setInterfacePopoutFileRename(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutFileRename() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutFileRename();

    Q_PROPERTY(bool interfacePopoutFilter READ getInterfacePopoutFilter WRITE setInterfacePopoutFilter NOTIFY interfacePopoutFilterChanged)
    bool getInterfacePopoutFilter() const;
    void setInterfacePopoutFilter(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutFilter() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutFilter();

    Q_PROPERTY(bool interfacePopoutFind READ getInterfacePopoutFind WRITE setInterfacePopoutFind NOTIFY interfacePopoutFindChanged)
    bool getInterfacePopoutFind() const;
    void setInterfacePopoutFind(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutFind() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutFind();

    Q_PROPERTY(bool interfacePopoutImgur READ getInterfacePopoutImgur WRITE setInterfacePopoutImgur NOTIFY interfacePopoutImgurChanged)
    bool getInterfacePopoutImgur() const;
    void setInterfacePopoutImgur(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutImgur() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutImgur();

    Q_PROPERTY(bool interfacePopoutMainMenu READ getInterfacePopoutMainMenu WRITE setInterfacePopoutMainMenu NOTIFY interfacePopoutMainMenuChanged)
    bool getInterfacePopoutMainMenu() const;
    void setInterfacePopoutMainMenu(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutMainMenu() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutMainMenu();

    Q_PROPERTY(bool interfacePopoutMapExplorer READ getInterfacePopoutMapExplorer WRITE setInterfacePopoutMapExplorer NOTIFY interfacePopoutMapExplorerChanged)
    bool getInterfacePopoutMapExplorer() const;
    void setInterfacePopoutMapExplorer(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutMapExplorer() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutMapExplorer();

    Q_PROPERTY(bool interfacePopoutMapExplorerNonModal READ getInterfacePopoutMapExplorerNonModal WRITE setInterfacePopoutMapExplorerNonModal NOTIFY interfacePopoutMapExplorerNonModalChanged)
    bool getInterfacePopoutMapExplorerNonModal() const;
    void setInterfacePopoutMapExplorerNonModal(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutMapExplorerNonModal() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutMapExplorerNonModal();

    Q_PROPERTY(bool interfacePopoutMetadata READ getInterfacePopoutMetadata WRITE setInterfacePopoutMetadata NOTIFY interfacePopoutMetadataChanged)
    bool getInterfacePopoutMetadata() const;
    void setInterfacePopoutMetadata(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutMetadata() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutMetadata();

    Q_PROPERTY(bool interfacePopoutSettingsManager READ getInterfacePopoutSettingsManager WRITE setInterfacePopoutSettingsManager NOTIFY interfacePopoutSettingsManagerChanged)
    bool getInterfacePopoutSettingsManager() const;
    void setInterfacePopoutSettingsManager(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutSettingsManager() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutSettingsManager();

    Q_PROPERTY(bool interfacePopoutSettingsManagerNonModal READ getInterfacePopoutSettingsManagerNonModal WRITE setInterfacePopoutSettingsManagerNonModal NOTIFY interfacePopoutSettingsManagerNonModalChanged)
    bool getInterfacePopoutSettingsManagerNonModal() const;
    void setInterfacePopoutSettingsManagerNonModal(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutSettingsManagerNonModal() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutSettingsManagerNonModal();

    Q_PROPERTY(bool interfacePopoutSlideshowControls READ getInterfacePopoutSlideshowControls WRITE setInterfacePopoutSlideshowControls NOTIFY interfacePopoutSlideshowControlsChanged)
    bool getInterfacePopoutSlideshowControls() const;
    void setInterfacePopoutSlideshowControls(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutSlideshowControls() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutSlideshowControls();

    Q_PROPERTY(bool interfacePopoutSlideshowSetup READ getInterfacePopoutSlideshowSetup WRITE setInterfacePopoutSlideshowSetup NOTIFY interfacePopoutSlideshowSetupChanged)
    bool getInterfacePopoutSlideshowSetup() const;
    void setInterfacePopoutSlideshowSetup(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutSlideshowSetup() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutSlideshowSetup();

    Q_PROPERTY(bool interfacePopoutWhenWindowIsSmall READ getInterfacePopoutWhenWindowIsSmall WRITE setInterfacePopoutWhenWindowIsSmall NOTIFY interfacePopoutWhenWindowIsSmallChanged)
    bool getInterfacePopoutWhenWindowIsSmall() const;
    void setInterfacePopoutWhenWindowIsSmall(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfacePopoutWhenWindowIsSmall() const;
    Q_INVOKABLE void setDefaultForInterfacePopoutWhenWindowIsSmall();

    Q_PROPERTY(bool interfaceQuickActions READ getInterfaceQuickActions WRITE setInterfaceQuickActions NOTIFY interfaceQuickActionsChanged)
    bool getInterfaceQuickActions() const;
    void setInterfaceQuickActions(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceQuickActions() const;
    Q_INVOKABLE void setDefaultForInterfaceQuickActions();

    Q_PROPERTY(int interfaceQuickActionsHeight READ getInterfaceQuickActionsHeight WRITE setInterfaceQuickActionsHeight NOTIFY interfaceQuickActionsHeightChanged)
    int getInterfaceQuickActionsHeight() const;
    void setInterfaceQuickActionsHeight(const int val);
    Q_INVOKABLE const int getDefaultForInterfaceQuickActionsHeight() const;
    Q_INVOKABLE void setDefaultForInterfaceQuickActionsHeight();

    Q_PROPERTY(QStringList interfaceQuickActionsItems READ getInterfaceQuickActionsItems WRITE setInterfaceQuickActionsItems NOTIFY interfaceQuickActionsItemsChanged)
    QStringList getInterfaceQuickActionsItems() const;
    void setInterfaceQuickActionsItems(const QStringList val);
    Q_INVOKABLE const QStringList getDefaultForInterfaceQuickActionsItems() const;
    Q_INVOKABLE void setDefaultForInterfaceQuickActionsItems();

    Q_PROPERTY(bool interfaceRememberLastImage READ getInterfaceRememberLastImage WRITE setInterfaceRememberLastImage NOTIFY interfaceRememberLastImageChanged)
    bool getInterfaceRememberLastImage() const;
    void setInterfaceRememberLastImage(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceRememberLastImage() const;
    Q_INVOKABLE void setDefaultForInterfaceRememberLastImage();

    Q_PROPERTY(bool interfaceSaveWindowGeometry READ getInterfaceSaveWindowGeometry WRITE setInterfaceSaveWindowGeometry NOTIFY interfaceSaveWindowGeometryChanged)
    bool getInterfaceSaveWindowGeometry() const;
    void setInterfaceSaveWindowGeometry(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceSaveWindowGeometry() const;
    Q_INVOKABLE void setDefaultForInterfaceSaveWindowGeometry();

    Q_PROPERTY(bool interfaceStatusInfoAutoHide READ getInterfaceStatusInfoAutoHide WRITE setInterfaceStatusInfoAutoHide NOTIFY interfaceStatusInfoAutoHideChanged)
    bool getInterfaceStatusInfoAutoHide() const;
    void setInterfaceStatusInfoAutoHide(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceStatusInfoAutoHide() const;
    Q_INVOKABLE void setDefaultForInterfaceStatusInfoAutoHide();

    Q_PROPERTY(int interfaceStatusInfoAutoHideTimeout READ getInterfaceStatusInfoAutoHideTimeout WRITE setInterfaceStatusInfoAutoHideTimeout NOTIFY interfaceStatusInfoAutoHideTimeoutChanged)
    int getInterfaceStatusInfoAutoHideTimeout() const;
    void setInterfaceStatusInfoAutoHideTimeout(const int val);
    Q_INVOKABLE const int getDefaultForInterfaceStatusInfoAutoHideTimeout() const;
    Q_INVOKABLE void setDefaultForInterfaceStatusInfoAutoHideTimeout();

    Q_PROPERTY(bool interfaceStatusInfoAutoHideTopEdge READ getInterfaceStatusInfoAutoHideTopEdge WRITE setInterfaceStatusInfoAutoHideTopEdge NOTIFY interfaceStatusInfoAutoHideTopEdgeChanged)
    bool getInterfaceStatusInfoAutoHideTopEdge() const;
    void setInterfaceStatusInfoAutoHideTopEdge(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceStatusInfoAutoHideTopEdge() const;
    Q_INVOKABLE void setDefaultForInterfaceStatusInfoAutoHideTopEdge();

    Q_PROPERTY(int interfaceStatusInfoFontSize READ getInterfaceStatusInfoFontSize WRITE setInterfaceStatusInfoFontSize NOTIFY interfaceStatusInfoFontSizeChanged)
    int getInterfaceStatusInfoFontSize() const;
    void setInterfaceStatusInfoFontSize(const int val);
    Q_INVOKABLE const int getDefaultForInterfaceStatusInfoFontSize() const;
    Q_INVOKABLE void setDefaultForInterfaceStatusInfoFontSize();

    Q_PROPERTY(QStringList interfaceStatusInfoList READ getInterfaceStatusInfoList WRITE setInterfaceStatusInfoList NOTIFY interfaceStatusInfoListChanged)
    QStringList getInterfaceStatusInfoList() const;
    void setInterfaceStatusInfoList(const QStringList val);
    Q_INVOKABLE const QStringList getDefaultForInterfaceStatusInfoList() const;
    Q_INVOKABLE void setDefaultForInterfaceStatusInfoList();

    Q_PROPERTY(bool interfaceStatusInfoManageWindow READ getInterfaceStatusInfoManageWindow WRITE setInterfaceStatusInfoManageWindow NOTIFY interfaceStatusInfoManageWindowChanged)
    bool getInterfaceStatusInfoManageWindow() const;
    void setInterfaceStatusInfoManageWindow(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceStatusInfoManageWindow() const;
    Q_INVOKABLE void setDefaultForInterfaceStatusInfoManageWindow();

    Q_PROPERTY(QString interfaceStatusInfoPosition READ getInterfaceStatusInfoPosition WRITE setInterfaceStatusInfoPosition NOTIFY interfaceStatusInfoPositionChanged)
    QString getInterfaceStatusInfoPosition() const;
    void setInterfaceStatusInfoPosition(const QString val);
    Q_INVOKABLE const QString getDefaultForInterfaceStatusInfoPosition() const;
    Q_INVOKABLE void setDefaultForInterfaceStatusInfoPosition();

    Q_PROPERTY(bool interfaceStatusInfoShow READ getInterfaceStatusInfoShow WRITE setInterfaceStatusInfoShow NOTIFY interfaceStatusInfoShowChanged)
    bool getInterfaceStatusInfoShow() const;
    void setInterfaceStatusInfoShow(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceStatusInfoShow() const;
    Q_INVOKABLE void setDefaultForInterfaceStatusInfoShow();

    Q_PROPERTY(bool interfaceStatusInfoShowImageChange READ getInterfaceStatusInfoShowImageChange WRITE setInterfaceStatusInfoShowImageChange NOTIFY interfaceStatusInfoShowImageChangeChanged)
    bool getInterfaceStatusInfoShowImageChange() const;
    void setInterfaceStatusInfoShowImageChange(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceStatusInfoShowImageChange() const;
    Q_INVOKABLE void setDefaultForInterfaceStatusInfoShowImageChange();

    Q_PROPERTY(int interfaceTrayIcon READ getInterfaceTrayIcon WRITE setInterfaceTrayIcon NOTIFY interfaceTrayIconChanged)
    int getInterfaceTrayIcon() const;
    void setInterfaceTrayIcon(const int val);
    Q_INVOKABLE const int getDefaultForInterfaceTrayIcon() const;
    Q_INVOKABLE void setDefaultForInterfaceTrayIcon();

    Q_PROPERTY(bool interfaceTrayIconHideReset READ getInterfaceTrayIconHideReset WRITE setInterfaceTrayIconHideReset NOTIFY interfaceTrayIconHideResetChanged)
    bool getInterfaceTrayIconHideReset() const;
    void setInterfaceTrayIconHideReset(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceTrayIconHideReset() const;
    Q_INVOKABLE void setDefaultForInterfaceTrayIconHideReset();

    Q_PROPERTY(bool interfaceTrayIconMonochrome READ getInterfaceTrayIconMonochrome WRITE setInterfaceTrayIconMonochrome NOTIFY interfaceTrayIconMonochromeChanged)
    bool getInterfaceTrayIconMonochrome() const;
    void setInterfaceTrayIconMonochrome(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceTrayIconMonochrome() const;
    Q_INVOKABLE void setDefaultForInterfaceTrayIconMonochrome();

    Q_PROPERTY(bool interfaceWindowButtonsAutoHide READ getInterfaceWindowButtonsAutoHide WRITE setInterfaceWindowButtonsAutoHide NOTIFY interfaceWindowButtonsAutoHideChanged)
    bool getInterfaceWindowButtonsAutoHide() const;
    void setInterfaceWindowButtonsAutoHide(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceWindowButtonsAutoHide() const;
    Q_INVOKABLE void setDefaultForInterfaceWindowButtonsAutoHide();

    Q_PROPERTY(int interfaceWindowButtonsAutoHideTimeout READ getInterfaceWindowButtonsAutoHideTimeout WRITE setInterfaceWindowButtonsAutoHideTimeout NOTIFY interfaceWindowButtonsAutoHideTimeoutChanged)
    int getInterfaceWindowButtonsAutoHideTimeout() const;
    void setInterfaceWindowButtonsAutoHideTimeout(const int val);
    Q_INVOKABLE const int getDefaultForInterfaceWindowButtonsAutoHideTimeout() const;
    Q_INVOKABLE void setDefaultForInterfaceWindowButtonsAutoHideTimeout();

    Q_PROPERTY(bool interfaceWindowButtonsAutoHideTopEdge READ getInterfaceWindowButtonsAutoHideTopEdge WRITE setInterfaceWindowButtonsAutoHideTopEdge NOTIFY interfaceWindowButtonsAutoHideTopEdgeChanged)
    bool getInterfaceWindowButtonsAutoHideTopEdge() const;
    void setInterfaceWindowButtonsAutoHideTopEdge(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceWindowButtonsAutoHideTopEdge() const;
    Q_INVOKABLE void setDefaultForInterfaceWindowButtonsAutoHideTopEdge();

    Q_PROPERTY(bool interfaceWindowButtonsFollowAccentColor READ getInterfaceWindowButtonsFollowAccentColor WRITE setInterfaceWindowButtonsFollowAccentColor NOTIFY interfaceWindowButtonsFollowAccentColorChanged)
    bool getInterfaceWindowButtonsFollowAccentColor() const;
    void setInterfaceWindowButtonsFollowAccentColor(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceWindowButtonsFollowAccentColor() const;
    Q_INVOKABLE void setDefaultForInterfaceWindowButtonsFollowAccentColor();

    Q_PROPERTY(QStringList interfaceWindowButtonsItems READ getInterfaceWindowButtonsItems WRITE setInterfaceWindowButtonsItems NOTIFY interfaceWindowButtonsItemsChanged)
    QStringList getInterfaceWindowButtonsItems() const;
    void setInterfaceWindowButtonsItems(const QStringList val);
    Q_INVOKABLE const QStringList getDefaultForInterfaceWindowButtonsItems() const;
    Q_INVOKABLE void setDefaultForInterfaceWindowButtonsItems();

    Q_PROPERTY(bool interfaceWindowButtonsShow READ getInterfaceWindowButtonsShow WRITE setInterfaceWindowButtonsShow NOTIFY interfaceWindowButtonsShowChanged)
    bool getInterfaceWindowButtonsShow() const;
    void setInterfaceWindowButtonsShow(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceWindowButtonsShow() const;
    Q_INVOKABLE void setDefaultForInterfaceWindowButtonsShow();

    Q_PROPERTY(int interfaceWindowButtonsSize READ getInterfaceWindowButtonsSize WRITE setInterfaceWindowButtonsSize NOTIFY interfaceWindowButtonsSizeChanged)
    int getInterfaceWindowButtonsSize() const;
    void setInterfaceWindowButtonsSize(const int val);
    Q_INVOKABLE const int getDefaultForInterfaceWindowButtonsSize() const;
    Q_INVOKABLE void setDefaultForInterfaceWindowButtonsSize();

    Q_PROPERTY(bool interfaceWindowDecoration READ getInterfaceWindowDecoration WRITE setInterfaceWindowDecoration NOTIFY interfaceWindowDecorationChanged)
    bool getInterfaceWindowDecoration() const;
    void setInterfaceWindowDecoration(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceWindowDecoration() const;
    Q_INVOKABLE void setDefaultForInterfaceWindowDecoration();

    Q_PROPERTY(bool interfaceWindowDecorationOnEmptyBackground READ getInterfaceWindowDecorationOnEmptyBackground WRITE setInterfaceWindowDecorationOnEmptyBackground NOTIFY interfaceWindowDecorationOnEmptyBackgroundChanged)
    bool getInterfaceWindowDecorationOnEmptyBackground() const;
    void setInterfaceWindowDecorationOnEmptyBackground(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceWindowDecorationOnEmptyBackground() const;
    Q_INVOKABLE void setDefaultForInterfaceWindowDecorationOnEmptyBackground();

    Q_PROPERTY(bool interfaceWindowMode READ getInterfaceWindowMode WRITE setInterfaceWindowMode NOTIFY interfaceWindowModeChanged)
    bool getInterfaceWindowMode() const;
    void setInterfaceWindowMode(const bool val);
    Q_INVOKABLE const bool getDefaultForInterfaceWindowMode() const;
    Q_INVOKABLE void setDefaultForInterfaceWindowMode();

    /**************************************/
    // table: mainmenu

    Q_PROPERTY(bool mainmenuElementHeightDynamic READ getMainmenuElementHeightDynamic WRITE setMainmenuElementHeightDynamic NOTIFY mainmenuElementHeightDynamicChanged)
    bool getMainmenuElementHeightDynamic() const;
    void setMainmenuElementHeightDynamic(const bool val);
    Q_INVOKABLE const bool getDefaultForMainmenuElementHeightDynamic() const;
    Q_INVOKABLE void setDefaultForMainmenuElementHeightDynamic();

    Q_PROPERTY(QPointF mainmenuElementPosition READ getMainmenuElementPosition WRITE setMainmenuElementPosition NOTIFY mainmenuElementPositionChanged)
    QPointF getMainmenuElementPosition() const;
    void setMainmenuElementPosition(const QPointF val);
    Q_INVOKABLE const QPointF getDefaultForMainmenuElementPosition() const;
    Q_INVOKABLE void setDefaultForMainmenuElementPosition();

    Q_PROPERTY(QSizeF mainmenuElementSize READ getMainmenuElementSize WRITE setMainmenuElementSize NOTIFY mainmenuElementSizeChanged)
    QSizeF getMainmenuElementSize() const;
    void setMainmenuElementSize(const QSizeF val);
    Q_INVOKABLE const QSizeF getDefaultForMainmenuElementSize() const;
    Q_INVOKABLE void setDefaultForMainmenuElementSize();

    Q_PROPERTY(int mainmenuElementWidth READ getMainmenuElementWidth WRITE setMainmenuElementWidth NOTIFY mainmenuElementWidthChanged)
    int getMainmenuElementWidth() const;
    void setMainmenuElementWidth(const int val);
    Q_INVOKABLE const int getDefaultForMainmenuElementWidth() const;
    Q_INVOKABLE void setDefaultForMainmenuElementWidth();

    Q_PROPERTY(bool mainmenuShowExternal READ getMainmenuShowExternal WRITE setMainmenuShowExternal NOTIFY mainmenuShowExternalChanged)
    bool getMainmenuShowExternal() const;
    void setMainmenuShowExternal(const bool val);
    Q_INVOKABLE const bool getDefaultForMainmenuShowExternal() const;
    Q_INVOKABLE void setDefaultForMainmenuShowExternal();

    /**************************************/
    // table: mapview

    Q_PROPERTY(QPointF mapviewCurrentPosition READ getMapviewCurrentPosition WRITE setMapviewCurrentPosition NOTIFY mapviewCurrentPositionChanged)
    QPointF getMapviewCurrentPosition() const;
    void setMapviewCurrentPosition(const QPointF val);
    Q_INVOKABLE const QPointF getDefaultForMapviewCurrentPosition() const;
    Q_INVOKABLE void setDefaultForMapviewCurrentPosition();

    Q_PROPERTY(QSizeF mapviewCurrentSize READ getMapviewCurrentSize WRITE setMapviewCurrentSize NOTIFY mapviewCurrentSizeChanged)
    QSizeF getMapviewCurrentSize() const;
    void setMapviewCurrentSize(const QSizeF val);
    Q_INVOKABLE const QSizeF getDefaultForMapviewCurrentSize() const;
    Q_INVOKABLE void setDefaultForMapviewCurrentSize();

    Q_PROPERTY(bool mapviewCurrentVisible READ getMapviewCurrentVisible WRITE setMapviewCurrentVisible NOTIFY mapviewCurrentVisibleChanged)
    bool getMapviewCurrentVisible() const;
    void setMapviewCurrentVisible(const bool val);
    Q_INVOKABLE const bool getDefaultForMapviewCurrentVisible() const;
    Q_INVOKABLE void setDefaultForMapviewCurrentVisible();

    Q_PROPERTY(bool mapviewExplorerThumbnailsScaleCrop READ getMapviewExplorerThumbnailsScaleCrop WRITE setMapviewExplorerThumbnailsScaleCrop NOTIFY mapviewExplorerThumbnailsScaleCropChanged)
    bool getMapviewExplorerThumbnailsScaleCrop() const;
    void setMapviewExplorerThumbnailsScaleCrop(const bool val);
    Q_INVOKABLE const bool getDefaultForMapviewExplorerThumbnailsScaleCrop() const;
    Q_INVOKABLE void setDefaultForMapviewExplorerThumbnailsScaleCrop();

    Q_PROPERTY(int mapviewExplorerThumbnailsZoomLevel READ getMapviewExplorerThumbnailsZoomLevel WRITE setMapviewExplorerThumbnailsZoomLevel NOTIFY mapviewExplorerThumbnailsZoomLevelChanged)
    int getMapviewExplorerThumbnailsZoomLevel() const;
    void setMapviewExplorerThumbnailsZoomLevel(const int val);
    Q_INVOKABLE const int getDefaultForMapviewExplorerThumbnailsZoomLevel() const;
    Q_INVOKABLE void setDefaultForMapviewExplorerThumbnailsZoomLevel();

    /**************************************/
    // table: metadata

    Q_PROPERTY(bool metadataAutoRotation READ getMetadataAutoRotation WRITE setMetadataAutoRotation NOTIFY metadataAutoRotationChanged)
    bool getMetadataAutoRotation() const;
    void setMetadataAutoRotation(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataAutoRotation() const;
    Q_INVOKABLE void setDefaultForMetadataAutoRotation();

    Q_PROPERTY(bool metadataCopyright READ getMetadataCopyright WRITE setMetadataCopyright NOTIFY metadataCopyrightChanged)
    bool getMetadataCopyright() const;
    void setMetadataCopyright(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataCopyright() const;
    Q_INVOKABLE void setDefaultForMetadataCopyright();

    Q_PROPERTY(bool metadataDimensions READ getMetadataDimensions WRITE setMetadataDimensions NOTIFY metadataDimensionsChanged)
    bool getMetadataDimensions() const;
    void setMetadataDimensions(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataDimensions() const;
    Q_INVOKABLE void setDefaultForMetadataDimensions();

    Q_PROPERTY(bool metadataElementFloating READ getMetadataElementFloating WRITE setMetadataElementFloating NOTIFY metadataElementFloatingChanged)
    bool getMetadataElementFloating() const;
    void setMetadataElementFloating(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataElementFloating() const;
    Q_INVOKABLE void setDefaultForMetadataElementFloating();

    Q_PROPERTY(bool metadataElementHeightDynamic READ getMetadataElementHeightDynamic WRITE setMetadataElementHeightDynamic NOTIFY metadataElementHeightDynamicChanged)
    bool getMetadataElementHeightDynamic() const;
    void setMetadataElementHeightDynamic(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataElementHeightDynamic() const;
    Q_INVOKABLE void setDefaultForMetadataElementHeightDynamic();

    Q_PROPERTY(QPointF metadataElementPosition READ getMetadataElementPosition WRITE setMetadataElementPosition NOTIFY metadataElementPositionChanged)
    QPointF getMetadataElementPosition() const;
    void setMetadataElementPosition(const QPointF val);
    Q_INVOKABLE const QPointF getDefaultForMetadataElementPosition() const;
    Q_INVOKABLE void setDefaultForMetadataElementPosition();

    Q_PROPERTY(QSizeF metadataElementSize READ getMetadataElementSize WRITE setMetadataElementSize NOTIFY metadataElementSizeChanged)
    QSizeF getMetadataElementSize() const;
    void setMetadataElementSize(const QSizeF val);
    Q_INVOKABLE const QSizeF getDefaultForMetadataElementSize() const;
    Q_INVOKABLE void setDefaultForMetadataElementSize();

    Q_PROPERTY(bool metadataElementVisible READ getMetadataElementVisible WRITE setMetadataElementVisible NOTIFY metadataElementVisibleChanged)
    bool getMetadataElementVisible() const;
    void setMetadataElementVisible(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataElementVisible() const;
    Q_INVOKABLE void setDefaultForMetadataElementVisible();

    Q_PROPERTY(bool metadataExposureTime READ getMetadataExposureTime WRITE setMetadataExposureTime NOTIFY metadataExposureTimeChanged)
    bool getMetadataExposureTime() const;
    void setMetadataExposureTime(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataExposureTime() const;
    Q_INVOKABLE void setDefaultForMetadataExposureTime();

    Q_PROPERTY(bool metadataFLength READ getMetadataFLength WRITE setMetadataFLength NOTIFY metadataFLengthChanged)
    bool getMetadataFLength() const;
    void setMetadataFLength(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataFLength() const;
    Q_INVOKABLE void setDefaultForMetadataFLength();

    Q_PROPERTY(bool metadataFNumber READ getMetadataFNumber WRITE setMetadataFNumber NOTIFY metadataFNumberChanged)
    bool getMetadataFNumber() const;
    void setMetadataFNumber(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataFNumber() const;
    Q_INVOKABLE void setDefaultForMetadataFNumber();

    Q_PROPERTY(bool metadataFaceTagsBorder READ getMetadataFaceTagsBorder WRITE setMetadataFaceTagsBorder NOTIFY metadataFaceTagsBorderChanged)
    bool getMetadataFaceTagsBorder() const;
    void setMetadataFaceTagsBorder(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataFaceTagsBorder() const;
    Q_INVOKABLE void setDefaultForMetadataFaceTagsBorder();

    Q_PROPERTY(QString metadataFaceTagsBorderColor READ getMetadataFaceTagsBorderColor WRITE setMetadataFaceTagsBorderColor NOTIFY metadataFaceTagsBorderColorChanged)
    QString getMetadataFaceTagsBorderColor() const;
    void setMetadataFaceTagsBorderColor(const QString val);
    Q_INVOKABLE const QString getDefaultForMetadataFaceTagsBorderColor() const;
    Q_INVOKABLE void setDefaultForMetadataFaceTagsBorderColor();

    Q_PROPERTY(int metadataFaceTagsBorderWidth READ getMetadataFaceTagsBorderWidth WRITE setMetadataFaceTagsBorderWidth NOTIFY metadataFaceTagsBorderWidthChanged)
    int getMetadataFaceTagsBorderWidth() const;
    void setMetadataFaceTagsBorderWidth(const int val);
    Q_INVOKABLE const int getDefaultForMetadataFaceTagsBorderWidth() const;
    Q_INVOKABLE void setDefaultForMetadataFaceTagsBorderWidth();

    Q_PROPERTY(bool metadataFaceTagsEnabled READ getMetadataFaceTagsEnabled WRITE setMetadataFaceTagsEnabled NOTIFY metadataFaceTagsEnabledChanged)
    bool getMetadataFaceTagsEnabled() const;
    void setMetadataFaceTagsEnabled(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataFaceTagsEnabled() const;
    Q_INVOKABLE void setDefaultForMetadataFaceTagsEnabled();

    Q_PROPERTY(int metadataFaceTagsFontSize READ getMetadataFaceTagsFontSize WRITE setMetadataFaceTagsFontSize NOTIFY metadataFaceTagsFontSizeChanged)
    int getMetadataFaceTagsFontSize() const;
    void setMetadataFaceTagsFontSize(const int val);
    Q_INVOKABLE const int getDefaultForMetadataFaceTagsFontSize() const;
    Q_INVOKABLE void setDefaultForMetadataFaceTagsFontSize();

    Q_PROPERTY(int metadataFaceTagsVisibility READ getMetadataFaceTagsVisibility WRITE setMetadataFaceTagsVisibility NOTIFY metadataFaceTagsVisibilityChanged)
    int getMetadataFaceTagsVisibility() const;
    void setMetadataFaceTagsVisibility(const int val);
    Q_INVOKABLE const int getDefaultForMetadataFaceTagsVisibility() const;
    Q_INVOKABLE void setDefaultForMetadataFaceTagsVisibility();

    Q_PROPERTY(bool metadataFileSize READ getMetadataFileSize WRITE setMetadataFileSize NOTIFY metadataFileSizeChanged)
    bool getMetadataFileSize() const;
    void setMetadataFileSize(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataFileSize() const;
    Q_INVOKABLE void setDefaultForMetadataFileSize();

    Q_PROPERTY(bool metadataFileType READ getMetadataFileType WRITE setMetadataFileType NOTIFY metadataFileTypeChanged)
    bool getMetadataFileType() const;
    void setMetadataFileType(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataFileType() const;
    Q_INVOKABLE void setDefaultForMetadataFileType();

    Q_PROPERTY(bool metadataFilename READ getMetadataFilename WRITE setMetadataFilename NOTIFY metadataFilenameChanged)
    bool getMetadataFilename() const;
    void setMetadataFilename(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataFilename() const;
    Q_INVOKABLE void setDefaultForMetadataFilename();

    Q_PROPERTY(bool metadataFlash READ getMetadataFlash WRITE setMetadataFlash NOTIFY metadataFlashChanged)
    bool getMetadataFlash() const;
    void setMetadataFlash(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataFlash() const;
    Q_INVOKABLE void setDefaultForMetadataFlash();

    Q_PROPERTY(bool metadataGps READ getMetadataGps WRITE setMetadataGps NOTIFY metadataGpsChanged)
    bool getMetadataGps() const;
    void setMetadataGps(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataGps() const;
    Q_INVOKABLE void setDefaultForMetadataGps();

    Q_PROPERTY(QString metadataGpsMap READ getMetadataGpsMap WRITE setMetadataGpsMap NOTIFY metadataGpsMapChanged)
    QString getMetadataGpsMap() const;
    void setMetadataGpsMap(const QString val);
    Q_INVOKABLE const QString getDefaultForMetadataGpsMap() const;
    Q_INVOKABLE void setDefaultForMetadataGpsMap();

    Q_PROPERTY(bool metadataImageNumber READ getMetadataImageNumber WRITE setMetadataImageNumber NOTIFY metadataImageNumberChanged)
    bool getMetadataImageNumber() const;
    void setMetadataImageNumber(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataImageNumber() const;
    Q_INVOKABLE void setDefaultForMetadataImageNumber();

    Q_PROPERTY(bool metadataIso READ getMetadataIso WRITE setMetadataIso NOTIFY metadataIsoChanged)
    bool getMetadataIso() const;
    void setMetadataIso(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataIso() const;
    Q_INVOKABLE void setDefaultForMetadataIso();

    Q_PROPERTY(bool metadataKeywords READ getMetadataKeywords WRITE setMetadataKeywords NOTIFY metadataKeywordsChanged)
    bool getMetadataKeywords() const;
    void setMetadataKeywords(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataKeywords() const;
    Q_INVOKABLE void setDefaultForMetadataKeywords();

    Q_PROPERTY(bool metadataLightSource READ getMetadataLightSource WRITE setMetadataLightSource NOTIFY metadataLightSourceChanged)
    bool getMetadataLightSource() const;
    void setMetadataLightSource(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataLightSource() const;
    Q_INVOKABLE void setDefaultForMetadataLightSource();

    Q_PROPERTY(bool metadataLocation READ getMetadataLocation WRITE setMetadataLocation NOTIFY metadataLocationChanged)
    bool getMetadataLocation() const;
    void setMetadataLocation(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataLocation() const;
    Q_INVOKABLE void setDefaultForMetadataLocation();

    Q_PROPERTY(bool metadataMake READ getMetadataMake WRITE setMetadataMake NOTIFY metadataMakeChanged)
    bool getMetadataMake() const;
    void setMetadataMake(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataMake() const;
    Q_INVOKABLE void setDefaultForMetadataMake();

    Q_PROPERTY(bool metadataModel READ getMetadataModel WRITE setMetadataModel NOTIFY metadataModelChanged)
    bool getMetadataModel() const;
    void setMetadataModel(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataModel() const;
    Q_INVOKABLE void setDefaultForMetadataModel();

    Q_PROPERTY(bool metadataSceneType READ getMetadataSceneType WRITE setMetadataSceneType NOTIFY metadataSceneTypeChanged)
    bool getMetadataSceneType() const;
    void setMetadataSceneType(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataSceneType() const;
    Q_INVOKABLE void setDefaultForMetadataSceneType();

    Q_PROPERTY(bool metadataSideBar READ getMetadataSideBar WRITE setMetadataSideBar NOTIFY metadataSideBarChanged)
    bool getMetadataSideBar() const;
    void setMetadataSideBar(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataSideBar() const;
    Q_INVOKABLE void setDefaultForMetadataSideBar();

    Q_PROPERTY(QString metadataSideBarLocation READ getMetadataSideBarLocation WRITE setMetadataSideBarLocation NOTIFY metadataSideBarLocationChanged)
    QString getMetadataSideBarLocation() const;
    void setMetadataSideBarLocation(const QString val);
    Q_INVOKABLE const QString getDefaultForMetadataSideBarLocation() const;
    Q_INVOKABLE void setDefaultForMetadataSideBarLocation();

    Q_PROPERTY(int metadataSideBarWidth READ getMetadataSideBarWidth WRITE setMetadataSideBarWidth NOTIFY metadataSideBarWidthChanged)
    int getMetadataSideBarWidth() const;
    void setMetadataSideBarWidth(const int val);
    Q_INVOKABLE const int getDefaultForMetadataSideBarWidth() const;
    Q_INVOKABLE void setDefaultForMetadataSideBarWidth();

    Q_PROPERTY(bool metadataSoftware READ getMetadataSoftware WRITE setMetadataSoftware NOTIFY metadataSoftwareChanged)
    bool getMetadataSoftware() const;
    void setMetadataSoftware(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataSoftware() const;
    Q_INVOKABLE void setDefaultForMetadataSoftware();

    Q_PROPERTY(bool metadataTime READ getMetadataTime WRITE setMetadataTime NOTIFY metadataTimeChanged)
    bool getMetadataTime() const;
    void setMetadataTime(const bool val);
    Q_INVOKABLE const bool getDefaultForMetadataTime() const;
    Q_INVOKABLE void setDefaultForMetadataTime();

    /**************************************/
    // table: slideshow

    Q_PROPERTY(bool slideshowHideLabels READ getSlideshowHideLabels WRITE setSlideshowHideLabels NOTIFY slideshowHideLabelsChanged)
    bool getSlideshowHideLabels() const;
    void setSlideshowHideLabels(const bool val);
    Q_INVOKABLE const bool getDefaultForSlideshowHideLabels() const;
    Q_INVOKABLE void setDefaultForSlideshowHideLabels();

    Q_PROPERTY(bool slideshowHideWindowButtons READ getSlideshowHideWindowButtons WRITE setSlideshowHideWindowButtons NOTIFY slideshowHideWindowButtonsChanged)
    bool getSlideshowHideWindowButtons() const;
    void setSlideshowHideWindowButtons(const bool val);
    Q_INVOKABLE const bool getDefaultForSlideshowHideWindowButtons() const;
    Q_INVOKABLE void setDefaultForSlideshowHideWindowButtons();

    Q_PROPERTY(int slideshowImageTransition READ getSlideshowImageTransition WRITE setSlideshowImageTransition NOTIFY slideshowImageTransitionChanged)
    int getSlideshowImageTransition() const;
    void setSlideshowImageTransition(const int val);
    Q_INVOKABLE const int getDefaultForSlideshowImageTransition() const;
    Q_INVOKABLE void setDefaultForSlideshowImageTransition();

    Q_PROPERTY(bool slideshowIncludeSubFolders READ getSlideshowIncludeSubFolders WRITE setSlideshowIncludeSubFolders NOTIFY slideshowIncludeSubFoldersChanged)
    bool getSlideshowIncludeSubFolders() const;
    void setSlideshowIncludeSubFolders(const bool val);
    Q_INVOKABLE const bool getDefaultForSlideshowIncludeSubFolders() const;
    Q_INVOKABLE void setDefaultForSlideshowIncludeSubFolders();

    Q_PROPERTY(bool slideshowLoop READ getSlideshowLoop WRITE setSlideshowLoop NOTIFY slideshowLoopChanged)
    bool getSlideshowLoop() const;
    void setSlideshowLoop(const bool val);
    Q_INVOKABLE const bool getDefaultForSlideshowLoop() const;
    Q_INVOKABLE void setDefaultForSlideshowLoop();

    Q_PROPERTY(bool slideshowMusic READ getSlideshowMusic WRITE setSlideshowMusic NOTIFY slideshowMusicChanged)
    bool getSlideshowMusic() const;
    void setSlideshowMusic(const bool val);
    Q_INVOKABLE const bool getDefaultForSlideshowMusic() const;
    Q_INVOKABLE void setDefaultForSlideshowMusic();

    Q_PROPERTY(QString slideshowMusicFile READ getSlideshowMusicFile WRITE setSlideshowMusicFile NOTIFY slideshowMusicFileChanged)
    QString getSlideshowMusicFile() const;
    void setSlideshowMusicFile(const QString val);
    Q_INVOKABLE const QString getDefaultForSlideshowMusicFile() const;
    Q_INVOKABLE void setDefaultForSlideshowMusicFile();

    Q_PROPERTY(QStringList slideshowMusicFiles READ getSlideshowMusicFiles WRITE setSlideshowMusicFiles NOTIFY slideshowMusicFilesChanged)
    QStringList getSlideshowMusicFiles() const;
    void setSlideshowMusicFiles(const QStringList val);
    Q_INVOKABLE const QStringList getDefaultForSlideshowMusicFiles() const;
    Q_INVOKABLE void setDefaultForSlideshowMusicFiles();

    Q_PROPERTY(bool slideshowMusicShuffle READ getSlideshowMusicShuffle WRITE setSlideshowMusicShuffle NOTIFY slideshowMusicShuffleChanged)
    bool getSlideshowMusicShuffle() const;
    void setSlideshowMusicShuffle(const bool val);
    Q_INVOKABLE const bool getDefaultForSlideshowMusicShuffle() const;
    Q_INVOKABLE void setDefaultForSlideshowMusicShuffle();

    Q_PROPERTY(int slideshowMusicVolumeVideos READ getSlideshowMusicVolumeVideos WRITE setSlideshowMusicVolumeVideos NOTIFY slideshowMusicVolumeVideosChanged)
    int getSlideshowMusicVolumeVideos() const;
    void setSlideshowMusicVolumeVideos(const int val);
    Q_INVOKABLE const int getDefaultForSlideshowMusicVolumeVideos() const;
    Q_INVOKABLE void setDefaultForSlideshowMusicVolumeVideos();

    Q_PROPERTY(bool slideshowShuffle READ getSlideshowShuffle WRITE setSlideshowShuffle NOTIFY slideshowShuffleChanged)
    bool getSlideshowShuffle() const;
    void setSlideshowShuffle(const bool val);
    Q_INVOKABLE const bool getDefaultForSlideshowShuffle() const;
    Q_INVOKABLE void setDefaultForSlideshowShuffle();

    Q_PROPERTY(int slideshowTime READ getSlideshowTime WRITE setSlideshowTime NOTIFY slideshowTimeChanged)
    int getSlideshowTime() const;
    void setSlideshowTime(const int val);
    Q_INVOKABLE const int getDefaultForSlideshowTime() const;
    Q_INVOKABLE void setDefaultForSlideshowTime();

    Q_PROPERTY(QString slideshowTypeAnimation READ getSlideshowTypeAnimation WRITE setSlideshowTypeAnimation NOTIFY slideshowTypeAnimationChanged)
    QString getSlideshowTypeAnimation() const;
    void setSlideshowTypeAnimation(const QString val);
    Q_INVOKABLE const QString getDefaultForSlideshowTypeAnimation() const;
    Q_INVOKABLE void setDefaultForSlideshowTypeAnimation();

    /**************************************/
    // table: thumbnails

    Q_PROPERTY(bool thumbnailsCache READ getThumbnailsCache WRITE setThumbnailsCache NOTIFY thumbnailsCacheChanged)
    bool getThumbnailsCache() const;
    void setThumbnailsCache(const bool val);
    Q_INVOKABLE const bool getDefaultForThumbnailsCache() const;
    Q_INVOKABLE void setDefaultForThumbnailsCache();

    Q_PROPERTY(bool thumbnailsCacheBaseDirDefault READ getThumbnailsCacheBaseDirDefault WRITE setThumbnailsCacheBaseDirDefault NOTIFY thumbnailsCacheBaseDirDefaultChanged)
    bool getThumbnailsCacheBaseDirDefault() const;
    void setThumbnailsCacheBaseDirDefault(const bool val);
    Q_INVOKABLE const bool getDefaultForThumbnailsCacheBaseDirDefault() const;
    Q_INVOKABLE void setDefaultForThumbnailsCacheBaseDirDefault();

    Q_PROPERTY(QString thumbnailsCacheBaseDirLocation READ getThumbnailsCacheBaseDirLocation WRITE setThumbnailsCacheBaseDirLocation NOTIFY thumbnailsCacheBaseDirLocationChanged)
    QString getThumbnailsCacheBaseDirLocation() const;
    void setThumbnailsCacheBaseDirLocation(const QString val);
    Q_INVOKABLE const QString getDefaultForThumbnailsCacheBaseDirLocation() const;
    Q_INVOKABLE void setDefaultForThumbnailsCacheBaseDirLocation();

    Q_PROPERTY(bool thumbnailsCenterOnActive READ getThumbnailsCenterOnActive WRITE setThumbnailsCenterOnActive NOTIFY thumbnailsCenterOnActiveChanged)
    bool getThumbnailsCenterOnActive() const;
    void setThumbnailsCenterOnActive(const bool val);
    Q_INVOKABLE const bool getDefaultForThumbnailsCenterOnActive() const;
    Q_INVOKABLE void setDefaultForThumbnailsCenterOnActive();

    Q_PROPERTY(bool thumbnailsCropToFit READ getThumbnailsCropToFit WRITE setThumbnailsCropToFit NOTIFY thumbnailsCropToFitChanged)
    bool getThumbnailsCropToFit() const;
    void setThumbnailsCropToFit(const bool val);
    Q_INVOKABLE const bool getDefaultForThumbnailsCropToFit() const;
    Q_INVOKABLE void setDefaultForThumbnailsCropToFit();

    Q_PROPERTY(bool thumbnailsDisable READ getThumbnailsDisable WRITE setThumbnailsDisable NOTIFY thumbnailsDisableChanged)
    bool getThumbnailsDisable() const;
    void setThumbnailsDisable(const bool val);
    Q_INVOKABLE const bool getDefaultForThumbnailsDisable() const;
    Q_INVOKABLE void setDefaultForThumbnailsDisable();

    Q_PROPERTY(QString thumbnailsExcludeDropBox READ getThumbnailsExcludeDropBox WRITE setThumbnailsExcludeDropBox NOTIFY thumbnailsExcludeDropBoxChanged)
    QString getThumbnailsExcludeDropBox() const;
    void setThumbnailsExcludeDropBox(const QString val);
    Q_INVOKABLE const QString getDefaultForThumbnailsExcludeDropBox() const;
    Q_INVOKABLE void setDefaultForThumbnailsExcludeDropBox();

    Q_PROPERTY(QStringList thumbnailsExcludeFolders READ getThumbnailsExcludeFolders WRITE setThumbnailsExcludeFolders NOTIFY thumbnailsExcludeFoldersChanged)
    QStringList getThumbnailsExcludeFolders() const;
    void setThumbnailsExcludeFolders(const QStringList val);
    Q_INVOKABLE const QStringList getDefaultForThumbnailsExcludeFolders() const;
    Q_INVOKABLE void setDefaultForThumbnailsExcludeFolders();

    Q_PROPERTY(bool thumbnailsExcludeNetworkShares READ getThumbnailsExcludeNetworkShares WRITE setThumbnailsExcludeNetworkShares NOTIFY thumbnailsExcludeNetworkSharesChanged)
    bool getThumbnailsExcludeNetworkShares() const;
    void setThumbnailsExcludeNetworkShares(const bool val);
    Q_INVOKABLE const bool getDefaultForThumbnailsExcludeNetworkShares() const;
    Q_INVOKABLE void setDefaultForThumbnailsExcludeNetworkShares();

    Q_PROPERTY(QString thumbnailsExcludeNextcloud READ getThumbnailsExcludeNextcloud WRITE setThumbnailsExcludeNextcloud NOTIFY thumbnailsExcludeNextcloudChanged)
    QString getThumbnailsExcludeNextcloud() const;
    void setThumbnailsExcludeNextcloud(const QString val);
    Q_INVOKABLE const QString getDefaultForThumbnailsExcludeNextcloud() const;
    Q_INVOKABLE void setDefaultForThumbnailsExcludeNextcloud();

    Q_PROPERTY(QString thumbnailsExcludeOwnCloud READ getThumbnailsExcludeOwnCloud WRITE setThumbnailsExcludeOwnCloud NOTIFY thumbnailsExcludeOwnCloudChanged)
    QString getThumbnailsExcludeOwnCloud() const;
    void setThumbnailsExcludeOwnCloud(const QString val);
    Q_INVOKABLE const QString getDefaultForThumbnailsExcludeOwnCloud() const;
    Q_INVOKABLE void setDefaultForThumbnailsExcludeOwnCloud();

    Q_PROPERTY(bool thumbnailsFilename READ getThumbnailsFilename WRITE setThumbnailsFilename NOTIFY thumbnailsFilenameChanged)
    bool getThumbnailsFilename() const;
    void setThumbnailsFilename(const bool val);
    Q_INVOKABLE const bool getDefaultForThumbnailsFilename() const;
    Q_INVOKABLE void setDefaultForThumbnailsFilename();

    Q_PROPERTY(int thumbnailsFontSize READ getThumbnailsFontSize WRITE setThumbnailsFontSize NOTIFY thumbnailsFontSizeChanged)
    int getThumbnailsFontSize() const;
    void setThumbnailsFontSize(const int val);
    Q_INVOKABLE const int getDefaultForThumbnailsFontSize() const;
    Q_INVOKABLE void setDefaultForThumbnailsFontSize();

    Q_PROPERTY(QStringList thumbnailsHighlightAnimation READ getThumbnailsHighlightAnimation WRITE setThumbnailsHighlightAnimation NOTIFY thumbnailsHighlightAnimationChanged)
    QStringList getThumbnailsHighlightAnimation() const;
    void setThumbnailsHighlightAnimation(const QStringList val);
    Q_INVOKABLE const QStringList getDefaultForThumbnailsHighlightAnimation() const;
    Q_INVOKABLE void setDefaultForThumbnailsHighlightAnimation();

    Q_PROPERTY(int thumbnailsHighlightAnimationLiftUp READ getThumbnailsHighlightAnimationLiftUp WRITE setThumbnailsHighlightAnimationLiftUp NOTIFY thumbnailsHighlightAnimationLiftUpChanged)
    int getThumbnailsHighlightAnimationLiftUp() const;
    void setThumbnailsHighlightAnimationLiftUp(const int val);
    Q_INVOKABLE const int getDefaultForThumbnailsHighlightAnimationLiftUp() const;
    Q_INVOKABLE void setDefaultForThumbnailsHighlightAnimationLiftUp();

    Q_PROPERTY(bool thumbnailsIconsOnly READ getThumbnailsIconsOnly WRITE setThumbnailsIconsOnly NOTIFY thumbnailsIconsOnlyChanged)
    bool getThumbnailsIconsOnly() const;
    void setThumbnailsIconsOnly(const bool val);
    Q_INVOKABLE const bool getDefaultForThumbnailsIconsOnly() const;
    Q_INVOKABLE void setDefaultForThumbnailsIconsOnly();

    Q_PROPERTY(bool thumbnailsInactiveTransparent READ getThumbnailsInactiveTransparent WRITE setThumbnailsInactiveTransparent NOTIFY thumbnailsInactiveTransparentChanged)
    bool getThumbnailsInactiveTransparent() const;
    void setThumbnailsInactiveTransparent(const bool val);
    Q_INVOKABLE const bool getDefaultForThumbnailsInactiveTransparent() const;
    Q_INVOKABLE void setDefaultForThumbnailsInactiveTransparent();

    Q_PROPERTY(int thumbnailsMaxNumberThreads READ getThumbnailsMaxNumberThreads WRITE setThumbnailsMaxNumberThreads NOTIFY thumbnailsMaxNumberThreadsChanged)
    int getThumbnailsMaxNumberThreads() const;
    void setThumbnailsMaxNumberThreads(const int val);
    Q_INVOKABLE const int getDefaultForThumbnailsMaxNumberThreads() const;
    Q_INVOKABLE void setDefaultForThumbnailsMaxNumberThreads();

    Q_PROPERTY(bool thumbnailsSameHeightVaryWidth READ getThumbnailsSameHeightVaryWidth WRITE setThumbnailsSameHeightVaryWidth NOTIFY thumbnailsSameHeightVaryWidthChanged)
    bool getThumbnailsSameHeightVaryWidth() const;
    void setThumbnailsSameHeightVaryWidth(const bool val);
    Q_INVOKABLE const bool getDefaultForThumbnailsSameHeightVaryWidth() const;
    Q_INVOKABLE void setDefaultForThumbnailsSameHeightVaryWidth();

    Q_PROPERTY(int thumbnailsSize READ getThumbnailsSize WRITE setThumbnailsSize NOTIFY thumbnailsSizeChanged)
    int getThumbnailsSize() const;
    void setThumbnailsSize(const int val);
    Q_INVOKABLE const int getDefaultForThumbnailsSize() const;
    Q_INVOKABLE void setDefaultForThumbnailsSize();

    Q_PROPERTY(bool thumbnailsSmallThumbnailsKeepSmall READ getThumbnailsSmallThumbnailsKeepSmall WRITE setThumbnailsSmallThumbnailsKeepSmall NOTIFY thumbnailsSmallThumbnailsKeepSmallChanged)
    bool getThumbnailsSmallThumbnailsKeepSmall() const;
    void setThumbnailsSmallThumbnailsKeepSmall(const bool val);
    Q_INVOKABLE const bool getDefaultForThumbnailsSmallThumbnailsKeepSmall() const;
    Q_INVOKABLE void setDefaultForThumbnailsSmallThumbnailsKeepSmall();

    Q_PROPERTY(int thumbnailsSpacing READ getThumbnailsSpacing WRITE setThumbnailsSpacing NOTIFY thumbnailsSpacingChanged)
    int getThumbnailsSpacing() const;
    void setThumbnailsSpacing(const int val);
    Q_INVOKABLE const int getDefaultForThumbnailsSpacing() const;
    Q_INVOKABLE void setDefaultForThumbnailsSpacing();

    Q_PROPERTY(bool thumbnailsTooltip READ getThumbnailsTooltip WRITE setThumbnailsTooltip NOTIFY thumbnailsTooltipChanged)
    bool getThumbnailsTooltip() const;
    void setThumbnailsTooltip(const bool val);
    Q_INVOKABLE const bool getDefaultForThumbnailsTooltip() const;
    Q_INVOKABLE void setDefaultForThumbnailsTooltip();

    Q_PROPERTY(int thumbnailsVisibility READ getThumbnailsVisibility WRITE setThumbnailsVisibility NOTIFY thumbnailsVisibilityChanged)
    int getThumbnailsVisibility() const;
    void setThumbnailsVisibility(const int val);
    Q_INVOKABLE const int getDefaultForThumbnailsVisibility() const;
    Q_INVOKABLE void setDefaultForThumbnailsVisibility();

    void setDefault();
    void setDefaultFor(QString key);

    void readDB();

    bool backupDatabase();

    Q_INVOKABLE void commitDatabase();
    Q_INVOKABLE void closeDatabase();
    Q_INVOKABLE void reopenDatabase();
    Q_INVOKABLE QStringList updateFromCommandLine();

    QString verifyNameAndGetType(QString name);

    bool validateSettingsDatabase(bool skipDBHandling = false);
    bool validateSettingsValues(bool skipDBHandling = false);
    void setupFresh();

public Q_SLOTS:
    Q_INVOKABLE void resetToDefault();

private:

    // table: filedialog
    bool m_filedialogDetailsTooltip;
    bool m_filedialogDevices;
    bool m_filedialogDevicesShowTmpfs;
    bool m_filedialogDragDropFileviewGrid;
    bool m_filedialogDragDropFileviewList;
    bool m_filedialogDragDropFileviewMasonry;
    bool m_filedialogDragDropPlaces;
    int m_filedialogElementPadding;
    bool m_filedialogFolderContentThumbnails;
    bool m_filedialogFolderContentThumbnailsAutoload;
    bool m_filedialogFolderContentThumbnailsLoop;
    bool m_filedialogFolderContentThumbnailsScaleCrop;
    bool m_filedialogFolderContentThumbnailsSortAscending;
    QString m_filedialogFolderContentThumbnailsSortBy;
    int m_filedialogFolderContentThumbnailsSpeed;
    bool m_filedialogLabelsShowGrid;
    bool m_filedialogLabelsShowMasonry;
    QString m_filedialogLayout;
    bool m_filedialogPlaces;
    int m_filedialogPlacesWidth;
    bool m_filedialogPreview;
    bool m_filedialogPreviewBlur;
    int m_filedialogPreviewColorIntensity;
    bool m_filedialogPreviewCropToFit;
    bool m_filedialogPreviewHigherResolution;
    bool m_filedialogPreviewMuted;
    bool m_filedialogRememberSelection;
    bool m_filedialogShowHiddenFilesFolders;
    bool m_filedialogSingleClickSelect;
    bool m_filedialogStartupRestoreCustom;
    QString m_filedialogStartupRestoreCustomFolder;
    bool m_filedialogStartupRestoreHome;
    bool m_filedialogStartupRestorePrevious;
    bool m_filedialogThumbnailSizeFollowsGlobalThumbnails;
    bool m_filedialogThumbnails;
    bool m_filedialogThumbnailsScaleCrop;
    bool m_filedialogUseNativeFileDialog;
    int m_filedialogZoom;

    // table: filetypes
    bool m_filetypesAnimatedControls;
    bool m_filetypesAnimatedLeftRight;
    bool m_filetypesAnimatedSpacePause;
    bool m_filetypesArchiveAlwaysEnterAutomatically;
    bool m_filetypesArchiveControls;
    bool m_filetypesArchiveDontLoadMoreFilesThan;
    int m_filetypesArchiveDontLoadMoreFilesThanCount;
    bool m_filetypesArchiveIgnoreLargerThan;
    int m_filetypesArchiveIgnoreLargerThanSize;
    bool m_filetypesArchiveLeftRight;
    bool m_filetypesArchiveViewerModeExitButton;
    bool m_filetypesComicBookAlwaysEnterAutomatically;
    bool m_filetypesDocumentAlwaysEnterAutomatically;
    bool m_filetypesDocumentControls;
    bool m_filetypesDocumentLeftRight;
    bool m_filetypesDocumentViewerModeExitButton;
    bool m_filetypesExternalUnrar;
    bool m_filetypesLoadAppleLivePhotos;
    bool m_filetypesLoadMotionPhotos;
    bool m_filetypesMotionAutoPlay;
    bool m_filetypesMotionPhotoPlayPause;
    bool m_filetypesMotionSpacePause;
    int m_filetypesPDFQuality;
    bool m_filetypesPhotoSphereArrowKeys;
    bool m_filetypesPhotoSphereAutoLoad;
    bool m_filetypesPhotoSphereBigButton;
    bool m_filetypesPhotoSphereControls;
    bool m_filetypesPhotoSpherePanOnLoad;
    bool m_filetypesRAWUseEmbeddedIfAvailable;
    bool m_filetypesVideoAutoplay;
    QStringList m_filetypesVideoBackend;
    bool m_filetypesVideoLeftRightJumpVideo;
    bool m_filetypesVideoLoop;
    bool m_filetypesVideoSpacePause;
    QString m_filetypesVideoThumbnailer;
    int m_filetypesVideoVolume;

    // table: general
    bool m_generalAutoSaveSettings;
    bool m_generalCompactSettings;
    bool m_generalDisableAllAnimations;
    QStringList m_generalExtensionsAllowUntrusted;
    QStringList m_generalExtensionsEnabled;
    QStringList m_generalExtensionsFloatingSetup;
    QString m_generalInterfaceVariant;
    QString m_generalVersion;

    // table: imageview
    bool m_imageviewAdvancedSortAscending;
    QString m_imageviewAdvancedSortCriteria;
    QStringList m_imageviewAdvancedSortDateCriteria;
    QString m_imageviewAdvancedSortQuality;
    bool m_imageviewAlwaysActualSize;
    int m_imageviewAnimationDuration;
    QString m_imageviewAnimationType;
    int m_imageviewCache;
    QStringList m_imageviewColorSpaceContextMenu;
    QString m_imageviewColorSpaceDefault;
    bool m_imageviewColorSpaceEnable;
    bool m_imageviewColorSpaceLoadEmbedded;
    bool m_imageviewEscapeExitArchive;
    bool m_imageviewEscapeExitBarcodes;
    bool m_imageviewEscapeExitDocument;
    bool m_imageviewEscapeExitFilter;
    bool m_imageviewEscapeExitSphere;
    bool m_imageviewFitInWindow;
    int m_imageviewHideCursorTimeout;
    int m_imageviewInterpolationFullImage;
    bool m_imageviewLoopThroughFolder;
    int m_imageviewMargin;
    int m_imageviewMinimapSizeLevel;
    bool m_imageviewMirrorAnimate;
    int m_imageviewMouseWheelRepeatDelay;
    int m_imageviewPreloadInBackground;
    bool m_imageviewPreserveMirror;
    bool m_imageviewPreserveRotation;
    bool m_imageviewPreserveZoom;
    bool m_imageviewRememberZoomRotationMirror;
    bool m_imageviewRescalingSmooth;
    int m_imageviewRescalingWhichImages;
    int m_imageviewResetViewAutoHideTimeout;
    bool m_imageviewResetViewShow;
    bool m_imageviewRespectDevicePixelRatio;
    bool m_imageviewShowMinimap;
    int m_imageviewSiblingFileMaxIterations;
    int m_imageviewSiblingFileMaxLevelUp;
    int m_imageviewSiblingFilemaxLevelDown;
    bool m_imageviewSortImagesAscending;
    QString m_imageviewSortImagesBy;
    bool m_imageviewTransparencyMarker;
    bool m_imageviewUseMouseLeftButtonForImageMove;
    bool m_imageviewUseMouseWheelForImageMove;
    int m_imageviewZoomMax;
    bool m_imageviewZoomMaxEnabled;
    int m_imageviewZoomMin;
    bool m_imageviewZoomMinEnabled;
    int m_imageviewZoomSpeed;
    bool m_imageviewZoomSpeedRelative;
    bool m_imageviewZoomToCenter;

    // table: interface
    QString m_interfaceAccentColor;
    bool m_interfaceAllowMultipleInstances;
    bool m_interfaceBackgroundCustomOverlay;
    QString m_interfaceBackgroundCustomOverlayColor;
    bool m_interfaceBackgroundFullyTransparent;
    bool m_interfaceBackgroundImageCenter;
    QString m_interfaceBackgroundImagePath;
    bool m_interfaceBackgroundImageScale;
    bool m_interfaceBackgroundImageScaleCrop;
    bool m_interfaceBackgroundImageScreenshot;
    bool m_interfaceBackgroundImageStretch;
    bool m_interfaceBackgroundImageTile;
    bool m_interfaceBackgroundImageUse;
    bool m_interfaceBackgroundSolid;
    bool m_interfaceBlurElementsInBackground;
    bool m_interfaceCloseOnEmptyBackground;
    int m_interfaceDoubleClickThreshold;
    QString m_interfaceEdgeBottomAction;
    QString m_interfaceEdgeLeftAction;
    QString m_interfaceEdgeRightAction;
    QString m_interfaceEdgeTopAction;
    bool m_interfaceFlickAdjustSpeed;
    int m_interfaceFlickAdjustSpeedSpeedup;
    int m_interfaceFontBoldWeight;
    int m_interfaceFontNormalWeight;
    int m_interfaceHotEdgeSize;
    bool m_interfaceKeepWindowOnTop;
    QString m_interfaceLanguage;
    bool m_interfaceMinimapPopout;
    bool m_interfaceNavigateOnEmptyBackground;
    bool m_interfaceNavigationFloating;
    int m_interfaceNotificationDistanceFromEdge;
    QString m_interfaceNotificationLocation;
    bool m_interfaceNotificationTryNative;
    bool m_interfacePopoutAbout;
    bool m_interfacePopoutAdvancedSort;
    bool m_interfacePopoutChromecast;
    bool m_interfacePopoutExport;
    bool m_interfacePopoutFileDelete;
    bool m_interfacePopoutFileDialog;
    bool m_interfacePopoutFileDialogNonModal;
    bool m_interfacePopoutFileRename;
    bool m_interfacePopoutFilter;
    bool m_interfacePopoutFind;
    bool m_interfacePopoutImgur;
    bool m_interfacePopoutMainMenu;
    bool m_interfacePopoutMapExplorer;
    bool m_interfacePopoutMapExplorerNonModal;
    bool m_interfacePopoutMetadata;
    bool m_interfacePopoutSettingsManager;
    bool m_interfacePopoutSettingsManagerNonModal;
    bool m_interfacePopoutSlideshowControls;
    bool m_interfacePopoutSlideshowSetup;
    bool m_interfacePopoutWhenWindowIsSmall;
    bool m_interfaceQuickActions;
    int m_interfaceQuickActionsHeight;
    QStringList m_interfaceQuickActionsItems;
    bool m_interfaceRememberLastImage;
    bool m_interfaceSaveWindowGeometry;
    bool m_interfaceStatusInfoAutoHide;
    int m_interfaceStatusInfoAutoHideTimeout;
    bool m_interfaceStatusInfoAutoHideTopEdge;
    int m_interfaceStatusInfoFontSize;
    QStringList m_interfaceStatusInfoList;
    bool m_interfaceStatusInfoManageWindow;
    QString m_interfaceStatusInfoPosition;
    bool m_interfaceStatusInfoShow;
    bool m_interfaceStatusInfoShowImageChange;
    int m_interfaceTrayIcon;
    bool m_interfaceTrayIconHideReset;
    bool m_interfaceTrayIconMonochrome;
    bool m_interfaceWindowButtonsAutoHide;
    int m_interfaceWindowButtonsAutoHideTimeout;
    bool m_interfaceWindowButtonsAutoHideTopEdge;
    bool m_interfaceWindowButtonsFollowAccentColor;
    QStringList m_interfaceWindowButtonsItems;
    bool m_interfaceWindowButtonsShow;
    int m_interfaceWindowButtonsSize;
    bool m_interfaceWindowDecoration;
    bool m_interfaceWindowDecorationOnEmptyBackground;
    bool m_interfaceWindowMode;

    // table: mainmenu
    bool m_mainmenuElementHeightDynamic;
    QPointF m_mainmenuElementPosition;
    QSizeF m_mainmenuElementSize;
    int m_mainmenuElementWidth;
    bool m_mainmenuShowExternal;

    // table: mapview
    QPointF m_mapviewCurrentPosition;
    QSizeF m_mapviewCurrentSize;
    bool m_mapviewCurrentVisible;
    bool m_mapviewExplorerThumbnailsScaleCrop;
    int m_mapviewExplorerThumbnailsZoomLevel;

    // table: metadata
    bool m_metadataAutoRotation;
    bool m_metadataCopyright;
    bool m_metadataDimensions;
    bool m_metadataElementFloating;
    bool m_metadataElementHeightDynamic;
    QPointF m_metadataElementPosition;
    QSizeF m_metadataElementSize;
    bool m_metadataElementVisible;
    bool m_metadataExposureTime;
    bool m_metadataFLength;
    bool m_metadataFNumber;
    bool m_metadataFaceTagsBorder;
    QString m_metadataFaceTagsBorderColor;
    int m_metadataFaceTagsBorderWidth;
    bool m_metadataFaceTagsEnabled;
    int m_metadataFaceTagsFontSize;
    int m_metadataFaceTagsVisibility;
    bool m_metadataFileSize;
    bool m_metadataFileType;
    bool m_metadataFilename;
    bool m_metadataFlash;
    bool m_metadataGps;
    QString m_metadataGpsMap;
    bool m_metadataImageNumber;
    bool m_metadataIso;
    bool m_metadataKeywords;
    bool m_metadataLightSource;
    bool m_metadataLocation;
    bool m_metadataMake;
    bool m_metadataModel;
    bool m_metadataSceneType;
    bool m_metadataSideBar;
    QString m_metadataSideBarLocation;
    int m_metadataSideBarWidth;
    bool m_metadataSoftware;
    bool m_metadataTime;

    // table: slideshow
    bool m_slideshowHideLabels;
    bool m_slideshowHideWindowButtons;
    int m_slideshowImageTransition;
    bool m_slideshowIncludeSubFolders;
    bool m_slideshowLoop;
    bool m_slideshowMusic;
    QString m_slideshowMusicFile;
    QStringList m_slideshowMusicFiles;
    bool m_slideshowMusicShuffle;
    int m_slideshowMusicVolumeVideos;
    bool m_slideshowShuffle;
    int m_slideshowTime;
    QString m_slideshowTypeAnimation;

    // table: thumbnails
    bool m_thumbnailsCache;
    bool m_thumbnailsCacheBaseDirDefault;
    QString m_thumbnailsCacheBaseDirLocation;
    bool m_thumbnailsCenterOnActive;
    bool m_thumbnailsCropToFit;
    bool m_thumbnailsDisable;
    QString m_thumbnailsExcludeDropBox;
    QStringList m_thumbnailsExcludeFolders;
    bool m_thumbnailsExcludeNetworkShares;
    QString m_thumbnailsExcludeNextcloud;
    QString m_thumbnailsExcludeOwnCloud;
    bool m_thumbnailsFilename;
    int m_thumbnailsFontSize;
    QStringList m_thumbnailsHighlightAnimation;
    int m_thumbnailsHighlightAnimationLiftUp;
    bool m_thumbnailsIconsOnly;
    bool m_thumbnailsInactiveTransparent;
    int m_thumbnailsMaxNumberThreads;
    bool m_thumbnailsSameHeightVaryWidth;
    int m_thumbnailsSize;
    bool m_thumbnailsSmallThumbnailsKeepSmall;
    int m_thumbnailsSpacing;
    bool m_thumbnailsTooltip;
    int m_thumbnailsVisibility;

    QStringList dbtables;
    bool dbIsTransaction;
    QTimer *dbCommitTimer;

    bool readonly;
    void saveChangedValue(const QString &key, const QVariant &value);

Q_SIGNALS:

    // table: filedialog
    void filedialogDetailsTooltipChanged();
    void filedialogDevicesChanged();
    void filedialogDevicesShowTmpfsChanged();
    void filedialogDragDropFileviewGridChanged();
    void filedialogDragDropFileviewListChanged();
    void filedialogDragDropFileviewMasonryChanged();
    void filedialogDragDropPlacesChanged();
    void filedialogElementPaddingChanged();
    void filedialogFolderContentThumbnailsChanged();
    void filedialogFolderContentThumbnailsAutoloadChanged();
    void filedialogFolderContentThumbnailsLoopChanged();
    void filedialogFolderContentThumbnailsScaleCropChanged();
    void filedialogFolderContentThumbnailsSortAscendingChanged();
    void filedialogFolderContentThumbnailsSortByChanged();
    void filedialogFolderContentThumbnailsSpeedChanged();
    void filedialogLabelsShowGridChanged();
    void filedialogLabelsShowMasonryChanged();
    void filedialogLayoutChanged();
    void filedialogPlacesChanged();
    void filedialogPlacesWidthChanged();
    void filedialogPreviewChanged();
    void filedialogPreviewBlurChanged();
    void filedialogPreviewColorIntensityChanged();
    void filedialogPreviewCropToFitChanged();
    void filedialogPreviewHigherResolutionChanged();
    void filedialogPreviewMutedChanged();
    void filedialogRememberSelectionChanged();
    void filedialogShowHiddenFilesFoldersChanged();
    void filedialogSingleClickSelectChanged();
    void filedialogStartupRestoreCustomChanged();
    void filedialogStartupRestoreCustomFolderChanged();
    void filedialogStartupRestoreHomeChanged();
    void filedialogStartupRestorePreviousChanged();
    void filedialogThumbnailSizeFollowsGlobalThumbnailsChanged();
    void filedialogThumbnailsChanged();
    void filedialogThumbnailsScaleCropChanged();
    void filedialogUseNativeFileDialogChanged();
    void filedialogZoomChanged();

    // table: filetypes
    void filetypesAnimatedControlsChanged();
    void filetypesAnimatedLeftRightChanged();
    void filetypesAnimatedSpacePauseChanged();
    void filetypesArchiveAlwaysEnterAutomaticallyChanged();
    void filetypesArchiveControlsChanged();
    void filetypesArchiveDontLoadMoreFilesThanChanged();
    void filetypesArchiveDontLoadMoreFilesThanCountChanged();
    void filetypesArchiveIgnoreLargerThanChanged();
    void filetypesArchiveIgnoreLargerThanSizeChanged();
    void filetypesArchiveLeftRightChanged();
    void filetypesArchiveViewerModeExitButtonChanged();
    void filetypesComicBookAlwaysEnterAutomaticallyChanged();
    void filetypesDocumentAlwaysEnterAutomaticallyChanged();
    void filetypesDocumentControlsChanged();
    void filetypesDocumentLeftRightChanged();
    void filetypesDocumentViewerModeExitButtonChanged();
    void filetypesExternalUnrarChanged();
    void filetypesLoadAppleLivePhotosChanged();
    void filetypesLoadMotionPhotosChanged();
    void filetypesMotionAutoPlayChanged();
    void filetypesMotionPhotoPlayPauseChanged();
    void filetypesMotionSpacePauseChanged();
    void filetypesPDFQualityChanged();
    void filetypesPhotoSphereArrowKeysChanged();
    void filetypesPhotoSphereAutoLoadChanged();
    void filetypesPhotoSphereBigButtonChanged();
    void filetypesPhotoSphereControlsChanged();
    void filetypesPhotoSpherePanOnLoadChanged();
    void filetypesRAWUseEmbeddedIfAvailableChanged();
    void filetypesVideoAutoplayChanged();
    void filetypesVideoBackendChanged();
    void filetypesVideoLeftRightJumpVideoChanged();
    void filetypesVideoLoopChanged();
    void filetypesVideoSpacePauseChanged();
    void filetypesVideoThumbnailerChanged();
    void filetypesVideoVolumeChanged();

    // table: general
    void generalAutoSaveSettingsChanged();
    void generalCompactSettingsChanged();
    void generalDisableAllAnimationsChanged();
    void generalExtensionsAllowUntrustedChanged();
    void generalExtensionsEnabledChanged();
    void generalExtensionsFloatingSetupChanged();
    void generalInterfaceVariantChanged();
    void generalVersionChanged();

    // table: imageview
    void imageviewAdvancedSortAscendingChanged();
    void imageviewAdvancedSortCriteriaChanged();
    void imageviewAdvancedSortDateCriteriaChanged();
    void imageviewAdvancedSortQualityChanged();
    void imageviewAlwaysActualSizeChanged();
    void imageviewAnimationDurationChanged();
    void imageviewAnimationTypeChanged();
    void imageviewCacheChanged();
    void imageviewColorSpaceContextMenuChanged();
    void imageviewColorSpaceDefaultChanged();
    void imageviewColorSpaceEnableChanged();
    void imageviewColorSpaceLoadEmbeddedChanged();
    void imageviewEscapeExitArchiveChanged();
    void imageviewEscapeExitBarcodesChanged();
    void imageviewEscapeExitDocumentChanged();
    void imageviewEscapeExitFilterChanged();
    void imageviewEscapeExitSphereChanged();
    void imageviewFitInWindowChanged();
    void imageviewHideCursorTimeoutChanged();
    void imageviewInterpolationFullImageChanged();
    void imageviewLoopThroughFolderChanged();
    void imageviewMarginChanged();
    void imageviewMinimapSizeLevelChanged();
    void imageviewMirrorAnimateChanged();
    void imageviewMouseWheelRepeatDelayChanged();
    void imageviewPreloadInBackgroundChanged();
    void imageviewPreserveMirrorChanged();
    void imageviewPreserveRotationChanged();
    void imageviewPreserveZoomChanged();
    void imageviewRememberZoomRotationMirrorChanged();
    void imageviewRescalingSmoothChanged();
    void imageviewRescalingWhichImagesChanged();
    void imageviewResetViewAutoHideTimeoutChanged();
    void imageviewResetViewShowChanged();
    void imageviewRespectDevicePixelRatioChanged();
    void imageviewShowMinimapChanged();
    void imageviewSiblingFileMaxIterationsChanged();
    void imageviewSiblingFileMaxLevelUpChanged();
    void imageviewSiblingFilemaxLevelDownChanged();
    void imageviewSortImagesAscendingChanged();
    void imageviewSortImagesByChanged();
    void imageviewTransparencyMarkerChanged();
    void imageviewUseMouseLeftButtonForImageMoveChanged();
    void imageviewUseMouseWheelForImageMoveChanged();
    void imageviewZoomMaxChanged();
    void imageviewZoomMaxEnabledChanged();
    void imageviewZoomMinChanged();
    void imageviewZoomMinEnabledChanged();
    void imageviewZoomSpeedChanged();
    void imageviewZoomSpeedRelativeChanged();
    void imageviewZoomToCenterChanged();

    // table: interface
    void interfaceAccentColorChanged();
    void interfaceAllowMultipleInstancesChanged();
    void interfaceBackgroundCustomOverlayChanged();
    void interfaceBackgroundCustomOverlayColorChanged();
    void interfaceBackgroundFullyTransparentChanged();
    void interfaceBackgroundImageCenterChanged();
    void interfaceBackgroundImagePathChanged();
    void interfaceBackgroundImageScaleChanged();
    void interfaceBackgroundImageScaleCropChanged();
    void interfaceBackgroundImageScreenshotChanged();
    void interfaceBackgroundImageStretchChanged();
    void interfaceBackgroundImageTileChanged();
    void interfaceBackgroundImageUseChanged();
    void interfaceBackgroundSolidChanged();
    void interfaceBlurElementsInBackgroundChanged();
    void interfaceCloseOnEmptyBackgroundChanged();
    void interfaceDoubleClickThresholdChanged();
    void interfaceEdgeBottomActionChanged();
    void interfaceEdgeLeftActionChanged();
    void interfaceEdgeRightActionChanged();
    void interfaceEdgeTopActionChanged();
    void interfaceFlickAdjustSpeedChanged();
    void interfaceFlickAdjustSpeedSpeedupChanged();
    void interfaceFontBoldWeightChanged();
    void interfaceFontNormalWeightChanged();
    void interfaceHotEdgeSizeChanged();
    void interfaceKeepWindowOnTopChanged();
    void interfaceLanguageChanged();
    void interfaceMinimapPopoutChanged();
    void interfaceNavigateOnEmptyBackgroundChanged();
    void interfaceNavigationFloatingChanged();
    void interfaceNotificationDistanceFromEdgeChanged();
    void interfaceNotificationLocationChanged();
    void interfaceNotificationTryNativeChanged();
    void interfacePopoutAboutChanged();
    void interfacePopoutAdvancedSortChanged();
    void interfacePopoutChromecastChanged();
    void interfacePopoutExportChanged();
    void interfacePopoutFileDeleteChanged();
    void interfacePopoutFileDialogChanged();
    void interfacePopoutFileDialogNonModalChanged();
    void interfacePopoutFileRenameChanged();
    void interfacePopoutFilterChanged();
    void interfacePopoutFindChanged();
    void interfacePopoutImgurChanged();
    void interfacePopoutMainMenuChanged();
    void interfacePopoutMapExplorerChanged();
    void interfacePopoutMapExplorerNonModalChanged();
    void interfacePopoutMetadataChanged();
    void interfacePopoutSettingsManagerChanged();
    void interfacePopoutSettingsManagerNonModalChanged();
    void interfacePopoutSlideshowControlsChanged();
    void interfacePopoutSlideshowSetupChanged();
    void interfacePopoutWhenWindowIsSmallChanged();
    void interfaceQuickActionsChanged();
    void interfaceQuickActionsHeightChanged();
    void interfaceQuickActionsItemsChanged();
    void interfaceRememberLastImageChanged();
    void interfaceSaveWindowGeometryChanged();
    void interfaceStatusInfoAutoHideChanged();
    void interfaceStatusInfoAutoHideTimeoutChanged();
    void interfaceStatusInfoAutoHideTopEdgeChanged();
    void interfaceStatusInfoFontSizeChanged();
    void interfaceStatusInfoListChanged();
    void interfaceStatusInfoManageWindowChanged();
    void interfaceStatusInfoPositionChanged();
    void interfaceStatusInfoShowChanged();
    void interfaceStatusInfoShowImageChangeChanged();
    void interfaceTrayIconChanged();
    void interfaceTrayIconHideResetChanged();
    void interfaceTrayIconMonochromeChanged();
    void interfaceWindowButtonsAutoHideChanged();
    void interfaceWindowButtonsAutoHideTimeoutChanged();
    void interfaceWindowButtonsAutoHideTopEdgeChanged();
    void interfaceWindowButtonsFollowAccentColorChanged();
    void interfaceWindowButtonsItemsChanged();
    void interfaceWindowButtonsShowChanged();
    void interfaceWindowButtonsSizeChanged();
    void interfaceWindowDecorationChanged();
    void interfaceWindowDecorationOnEmptyBackgroundChanged();
    void interfaceWindowModeChanged();

    // table: mainmenu
    void mainmenuElementHeightDynamicChanged();
    void mainmenuElementPositionChanged();
    void mainmenuElementSizeChanged();
    void mainmenuElementWidthChanged();
    void mainmenuShowExternalChanged();

    // table: mapview
    void mapviewCurrentPositionChanged();
    void mapviewCurrentSizeChanged();
    void mapviewCurrentVisibleChanged();
    void mapviewExplorerThumbnailsScaleCropChanged();
    void mapviewExplorerThumbnailsZoomLevelChanged();

    // table: metadata
    void metadataAutoRotationChanged();
    void metadataCopyrightChanged();
    void metadataDimensionsChanged();
    void metadataElementFloatingChanged();
    void metadataElementHeightDynamicChanged();
    void metadataElementPositionChanged();
    void metadataElementSizeChanged();
    void metadataElementVisibleChanged();
    void metadataExposureTimeChanged();
    void metadataFLengthChanged();
    void metadataFNumberChanged();
    void metadataFaceTagsBorderChanged();
    void metadataFaceTagsBorderColorChanged();
    void metadataFaceTagsBorderWidthChanged();
    void metadataFaceTagsEnabledChanged();
    void metadataFaceTagsFontSizeChanged();
    void metadataFaceTagsVisibilityChanged();
    void metadataFileSizeChanged();
    void metadataFileTypeChanged();
    void metadataFilenameChanged();
    void metadataFlashChanged();
    void metadataGpsChanged();
    void metadataGpsMapChanged();
    void metadataImageNumberChanged();
    void metadataIsoChanged();
    void metadataKeywordsChanged();
    void metadataLightSourceChanged();
    void metadataLocationChanged();
    void metadataMakeChanged();
    void metadataModelChanged();
    void metadataSceneTypeChanged();
    void metadataSideBarChanged();
    void metadataSideBarLocationChanged();
    void metadataSideBarWidthChanged();
    void metadataSoftwareChanged();
    void metadataTimeChanged();

    // table: slideshow
    void slideshowHideLabelsChanged();
    void slideshowHideWindowButtonsChanged();
    void slideshowImageTransitionChanged();
    void slideshowIncludeSubFoldersChanged();
    void slideshowLoopChanged();
    void slideshowMusicChanged();
    void slideshowMusicFileChanged();
    void slideshowMusicFilesChanged();
    void slideshowMusicShuffleChanged();
    void slideshowMusicVolumeVideosChanged();
    void slideshowShuffleChanged();
    void slideshowTimeChanged();
    void slideshowTypeAnimationChanged();

    // table: thumbnails
    void thumbnailsCacheChanged();
    void thumbnailsCacheBaseDirDefaultChanged();
    void thumbnailsCacheBaseDirLocationChanged();
    void thumbnailsCenterOnActiveChanged();
    void thumbnailsCropToFitChanged();
    void thumbnailsDisableChanged();
    void thumbnailsExcludeDropBoxChanged();
    void thumbnailsExcludeFoldersChanged();
    void thumbnailsExcludeNetworkSharesChanged();
    void thumbnailsExcludeNextcloudChanged();
    void thumbnailsExcludeOwnCloudChanged();
    void thumbnailsFilenameChanged();
    void thumbnailsFontSizeChanged();
    void thumbnailsHighlightAnimationChanged();
    void thumbnailsHighlightAnimationLiftUpChanged();
    void thumbnailsIconsOnlyChanged();
    void thumbnailsInactiveTransparentChanged();
    void thumbnailsMaxNumberThreadsChanged();
    void thumbnailsSameHeightVaryWidthChanged();
    void thumbnailsSizeChanged();
    void thumbnailsSmallThumbnailsKeepSmallChanged();
    void thumbnailsSpacingChanged();
    void thumbnailsTooltipChanged();
    void thumbnailsVisibilityChanged();

};

